/* eslint-disable semi, no-multi-spaces, quotes, indent, no-tabs, yoda */
/* global worldScripts, system, missionVariables, player, mission, clock, randomName */

"use strict";

this.name	     = "LITF";
this.author	     = "BeeTLe BeTHLeHeM";
this.copyright	 = "2018 BeeTLe BeTHLeHeM";
this.description = "Main OSP file";
this.version	 = "0.10.0";
this.licence	 = "CC BY-NC-SA 4.0";

var _co  = null;
var _mi  = null;
var _bbs = null;
var _nav = null;

this.startUp = function () {
    _co = worldScripts.LITF_Common;
    _co.$init();

    _mi = worldScripts.LITF_Missions;
    _mi.$init();

    _bbs = worldScripts.LITF_BBS;

    _nav = worldScripts.LITF_Station_ALPHA;

    _co.$log("[LITF] startup - [LIFE IN THE FRONTIER v" + this.version + "]");

    this.$initOXPVariables();

    this.$checkOtherOXP();

    // Starting up
    if (this.litfVars.starting === true) {
        _co.$log("creating initial BBS items");
        _bbs.$createBBSItems();
        this.litfVars.starting = false;
    }

    this.$LITFinterface();
}

this.playerWillSaveGame = function () {
    _co.$log("[LITF] playerWillSaveGame");

    // Store variables in savegame
    missionVariables.litfCommander = JSON.stringify(this.litfCommander);
    missionVariables.litfVars = JSON.stringify(this.litfVars);
}

this.shipWillDockWithStation = function (station) {
    _co.$log("[LITF] shipWillDockWithStation");

    // Player is going to dock with a station
}

this.shipDockedWithStation = function () {
    _co.$log("[LITF] shipDockedWithStation");

    // Player has just docked with a station

    // Store system data for BBS generation - only if player has changed system
    if (this.litfVars.stationParams.id !== system.ID) {
        var stationParams = {
            systemId: system.ID,
            government: _co.$systemGovernment(),
            economy: _co.$systemEconomy(),
            techLevel: _co.$systemTechLevel()
        };

        this.litfVars.stationParams = stationParams;
    }

    this.$checkExpiredMissions();

    if (this.litfVars.config.debug === true) {
        this.$checkMissingPerson();
    }

    // BBS item generation
    if (this.litfVars.refreshBBS === true) {
        _bbs.$createBBSItems();
        this.litfVars.refreshBBS = false;
        this.litfVars.bbsItems = this.litfVars.bbsData.bbsItemsArr;
    } else {
        this.litfVars.bbsData.bbsItemsArr = this.litfVars.bbsItems;
    }

    this.$LITFinterface();
}

this.shipExitedWitchspace = function () {
    _co.$log("[LITF] shipExitedWitchspace");

    // Player has just exited a witchspace jump

    // New messages when changing system
    this.litfVars.refreshBBS = true;
    this.litfVars.bbsItems = null;

    // Console message if there is a mission to complete in the present system.
    if (this.litfCommander.activeMissions.length > 0) {
        var missionsHere = 0;

        for (var m = 0; m < this.litfCommander.activeMissions.length; m++) {
            var mObj = this.litfCommander.activeMissions[m];

            var mSystems = _bbs.$getMissionTask(mObj, mObj.currentTask).info.systems;
            _co.$log("system.ID = " + system.ID + " mSystems = " + JSON.stringify(mSystems));

            for (var s = 0; s < mSystems.length; s++) {
                if (mSystems[s].id === system.ID) {
                    missionsHere = missionsHere + 1;
                }
            }
        }

        _co.$log(missionsHere + " tasks can be completed in this system.");

        if (missionsHere > 0) {
            var pl = missionsHere > 1 ? "s" : "";
            player.commsMessage("You have " + missionsHere + " active BBS mission" + pl + " in this system.");
        }
    }
}

this.playerEnteredNewGalaxy = function (galaxyNumber) {
    _co.$log("[LITF] playerEnteredNewGalaxy");

    // Player changed galaxy

    // Re-Initializing

    this.litfCommander = {
        feedback: 0,
        activeMissions: [],
        busyCargo: false,
        busyPassenger: false,
        busyParcel: false,
        statistics: {
            missionAccepted: [],
            missionCompleted: [],
            missionFailed: [],
            feedbackGained: [],
            feedbackLost: []
            // creditsGained: []
        }
    };

    for (var g = 0; g < _co.groupsLabels.length; g++) {
        this.litfCommander.statistics.missionAccepted.push(0);
        this.litfCommander.statistics.missionCompleted.push(0);
        this.litfCommander.statistics.missionFailed.push(0);
        this.litfCommander.statistics.feedbackGained.push(0);
        this.litfCommander.statistics.feedbackLost.push(0);
        // this.litfCommander.statistics.creditsGained.push(0);
    }
}

// Add OXP interfaces to station screen (F4)
this.$LITFinterface = function () {
    _co.$log("[LITF] LITFinterface");

	player.ship.dockedStation.setInterface("LITF_bbs",
		{
			title: "Login to BBS",
			category: "Activity",
			summary: "Connect to local Bulletin Board System",
			callback: this.$accessBBS.bind(this)
		}
    );

	player.ship.dockedStation.setInterface("LITF_profile",
		{
			title: "Your online status",
			category: "Activity",
			summary: "Check your online feedback and accepted missions.",
			callback: this.$displayOnlineStatus.bind(this)
		}
	);

    if (this.litfVars.config.debug === true) {
        player.ship.dockedStation.setInterface("LITF_navigation",
            {
                title: "Disembark from your ship",
                category: "Activity",
                summary: "Go roaming through the station.",
                callback: this.$navigateStation.bind(this)
            }
        );
    }
}

this.$navigateStation = function () {
    _co.$log("[LITF] navigateStation");

    _nav.$init();
    _nav.$start();
}

// Open the BBS message list screen
this.$accessBBS = function () {
    _co.$log("[LITF] accessBBS");

    this.$checkExpiredMissions();

    var _bbs = worldScripts.LITF_BBS;

    this.litfVars.enterBBSFlag = true;

    _bbs.$run();
}

// Open the Online Profile screen
this.$displayOnlineStatus = function () {
    _co.$log("[LITF] displayOnlineStatus");

    var displayText = null;
    var opts = null;
    var choices = null;

    if (this.litfVars.statusPage === 0) {
        this.$checkExpiredMissions();

        displayText = "NAME: " + player.name;
        displayText += "                                        ";
        displayText += "FEEDBACK: " + _co.$getFeedbackRanking(this.litfCommander.feedback) + " (" + this.litfCommander.feedback + ")";
        displayText += "\n\n";

        var maxActiveMissions = parseInt(Math.abs(this.litfCommander.feedback) / 25) + 1;

        displayText += "-- ACTIVE MISSIONS (" + this.litfCommander.activeMissions.length + " / " + maxActiveMissions + ") --";
        displayText += "\n\n";

        if (this.litfCommander.activeMissions.length === 0) {
            displayText += ">> No active missions at the moment <<";
        } else {
            for (var m = 0; m < this.litfCommander.activeMissions.length; m++) {
                var mObj = this.litfCommander.activeMissions[m];

                var deadline = parseInt(mObj.startTime) + parseInt(mObj.timeAllowed);
                var timeText = _co.$formatTime(deadline, true);

                var missionText = "> ";

                if (this.litfVars.config.debug === true) {
                    missionText += "(" + mObj.groupId + "." + mObj.tasks[0].typeId + "." + mObj.index + ") ";
                }

                missionText += _bbs.$getMissionTask(mObj, mObj.currentTask).description;
                missionText += " Mission expires in " + timeText + ".";

                if (mObj.reward > 0) {
                    missionText += " Payment: " + mObj.reward + " credits.";
                }

                displayText += missionText + "\n\n";
            }
        }

        choices = {
            "QUIT": "Exit the profile page."
        };

        if (this.litfVars.config.debug === true) {
            choices["NEXTPAGE"] = "Go to the Statistics screen.";
        }

        opts = {
            title: "Online Profile Data",
            exitScreen: "GUI_SCREEN_INTERFACES",
            message: displayText,
            choices: choices
        };
    } else if (this.litfVars.statusPage === 1) {
        displayText = "";

        for (var g = 0; g < _co.groupsLabels.length; g++) {
            displayText += _co.groupsLabels[g] + ": ";

            displayText += "Accepted: " + this.litfCommander.statistics.missionAccepted[g] + ", ";
            displayText += "Completed: " + this.litfCommander.statistics.missionCompleted[g] + ", ";
            displayText += "Failed: " + this.litfCommander.statistics.missionFailed[g] + ", ";

            displayText += " Feedback: ";
            if (this.litfCommander.statistics.feedbackGained[g] > 0) {
                displayText += "+" + this.litfCommander.statistics.feedbackGained[g];
            } else {
                displayText += this.litfCommander.statistics.feedbackGained[g];
            }

            displayText += " / ";
            if (this.litfCommander.statistics.feedbackLost[g] > 0) {
                displayText += "-" + this.litfCommander.statistics.feedbackLost[g];
            } else {
                displayText += this.litfCommander.statistics.feedbackLost[g];
            }

            displayText += "\n";
        }

        choices = {
            "NEXTPAGE": "Go to the Profile screen.",
            "QUIT": "Exit the profile page."
        };

        opts = {
            title: "Online Statistics",
            exitScreen: "GUI_SCREEN_INTERFACES",
            message: displayText,
            choices: choices
        };
    }

    mission.runScreen(opts, this.$executeStatusAction);
}

this.$executeStatusAction = function (choice) {
    if (choice === "QUIT") {
        this.litfVars.statusPage = 0;
        this.$LITFinterface();
    } else if (choice === "NEXTPAGE") {
        this.litfVars.statusPage = this.litfVars.statusPage + 1;
        if (this.litfVars.statusPage > 1) { this.litfVars.statusPage = 0; }
        this.$displayOnlineStatus();
    }
}

// Check expired missions and delete them
this.$checkExpiredMissions = function () {
    var failed = [];

    if (this.litfCommander.activeMissions) {
        for (var am = 0; am < this.litfCommander.activeMissions.length; am++) {
            var amItem = this.litfCommander.activeMissions[am];

            var deadline = parseInt(amItem.startTime) + parseInt(amItem.timeAllowed) - clock.seconds;

            if (deadline < 0) { failed.push(amItem.missionId); }
        }

        _co.$log("failed = " + JSON.stringify(failed));

        if (failed.length > 0) {
            var pl = null;

            pl = failed.length > 1 ? "s" : "";
            player.commsMessage("Time expired: " + failed.length + " mission" + pl + " failed.");
            _co.$log("Time expired: " + failed.length + " mission" + pl + " failed.");

            // var removedPassengers = 0;
            // var deadPassengers = 0;

            // Delete failed missions from active missions list
            for (var fm = 0; fm < failed.length; fm++) {
                var ret = _bbs.$deleteActiveMission(failed[fm]);

                // removedPassengers = removedPassengers + ret.removedPassengers;
                // deadPassengers = deadPassengers + ret.deadPassengers;

                if (ret.cargo !== null) {
                    player.ship.removeAllCargo();
                    player.commsMessage("A shipment of " + ret.cargo + " has been removed from your ship.");
                }

                if (ret.parcel !== null) {
                    player.ship.removeParcel(ret.parcel);
                    var parcelDesc = ret.parcel.substring(ret.parcel.indexOf(" ") + 1);
                    player.commsMessage(parcelDesc + " has been removed from your ship.");
                }

                _co.$updateStatistics("missionFailed", ret.groupId, 1);

                // Get feedback penalty
                if (ret.groupId !== 3) {
                    _co.$setPlayerFeedback(-ret.feedback.lost);
                }
                _co.$updateStatistics("feedbackLost", ret.groupId, ret.feedback.lost);

                if (ret.removedPassengers > 0) {
                    pl = ret.removedPassengers > 1 ? "s" : "";
                    player.commsMessage("" + ret.removedPassengers + " passenger" + pl + " have left your ship!");

                    // Get feedback penalty (1 point per passenger)
                    if (ret.groupId !== 3) {
                        _co.$setPlayerFeedback(-ret.removedPassengers);
                    }
                    _co.$updateStatistics("feedbackLost", ret.groupId, ret.removedPassengers);
                }

                if (ret.deadPassengers > 0) {
                    pl = ret.deadPassengers > 1 ? "s" : "";
                    player.commsMessage("" + ret.deadPassengers + " dead passenger" + pl + " has been removed from your ship!");

                    // Get feedback penalty (3 point per passenger)
                    if (ret.groupId !== 3) {
                        _co.$setPlayerFeedback(-ret.deadPassengers * 3);
                    }
                    _co.$updateStatistics("feedbackLost", ret.groupId, ret.deadPassengers * 3);
                }
            }
        }
    }
}

this.$initOXPVariables = function () {
    // OXP player commander data

    if (missionVariables.litfCommander) {
        // Loading from savegame
        _co.$log("Loading litfCommander object");
        this.litfCommander = JSON.parse(missionVariables.litfCommander);
    } else {
        // Initializing
        this.litfCommander = {
            feedback: 0,
            activeMissions: [],
            busyCargo: false,
            busyPassenger: false,
            busyParcel: false,
            statistics: {
                missionAccepted: [],
                missionCompleted: [],
                missionFailed: [],
                feedbackGained: [],
                feedbackLost: []
                // creditsGained: []
            }
        };

        for (var g = 0; g < _co.groupsLabels.length; g++) {
            this.litfCommander.statistics.missionAccepted.push(0);
            this.litfCommander.statistics.missionCompleted.push(0);
            this.litfCommander.statistics.missionFailed.push(0);
            this.litfCommander.statistics.feedbackGained.push(0);
            this.litfCommander.statistics.feedbackLost.push(0);
            // this.litfCommander.statistics.creditsGained.push(0);
        }
    }

    // OXP variables and flags

    if (missionVariables.litfVars) {
        // Loading from savegame
        _co.$log("Loading litfVars object");
        this.litfVars = JSON.parse(missionVariables.litfVars);
    } else {
        this.litfVars = {
            starting: true,
            config: {
                enableLog: false,
                debug: false,
                disableMissionBackground: true
            },
            stationParams: {
                systemId: system.ID,
                government: _co.$systemGovernment(),
                economy: _co.$systemEconomy(),
                techLevel: _co.$systemTechLevel()
            },
            refreshBBS: true,
            bbsItems: null,
            enterBBSFlag: false,
            generalId: 1,
            bbsData: {
                bbsItemsArr: [],
                checkDuplicatesArr: [],
                selectedItem: 0,
                lastChoice: "02_NEXT_ITEM",
                firstItemIdx: 0,
                totalItems: 0,
                rowsSize: 14,
                bbsMode: 0, // 0 - item list, 1 - item details
                selectedItemObj: null
            },
            statusPage: 0,
            oxp: {}
        };
    }

    this.litfVars.config.debug = false;
    this.litfVars.config.enableLog = false;
}

this.$checkMissingPerson = function () {
    _co.$log("[LITF] checkMissingPerson");

    if (!this.litfVars.missingPerson || this.litfVars.missingPerson === null) {
        var mPerson = {};

        mPerson.name = randomName() + " " + randomName();
        mPerson.currentPos = 0;
        mPerson.active = false;

        mPerson.posArr = this.$defineMissingPersonTravel();
        mPerson.nextMove = clock.seconds + (_co.$roll(4, 16) * 3600);

        _co.$log("missingPerson = " + JSON.stringify(mPerson));

        this.litfVars.missingPerson = mPerson;
    }
}

this.$defineMissingPersonTravel = function () {
    _co.$log("[LITF] defineMissingPersonTravel");

    var posArr = [];
    var jumps = 0;

    var firstSystem = _co.$randomSystem(-1);
    posArr.push(firstSystem.id);

    var enough = false;
    while (enough === false) {
        var startSystem = posArr[posArr.length - 1];
        var endSystem = null;

        var valid = false;
        while (valid === false) {
            valid = true;
            endSystem = _co.$randomSystem(-1);
            for (var s = 0; s < posArr.length; s++) {
                if (posArr[s].id === endSystem.id) {
                    valid = false;
                }
            }
        }

        _co.$log("startSystem[" + startSystem + "] endSystem[" + endSystem + "]");

        var systemRoute = _co.$getSystemRoute(startSystem, endSystem.id);
        jumps += systemRoute.route.length;

        _co.$log("jumps = " + jumps);

        for (var sr = 1; sr < systemRoute.route.length; sr++) {
            posArr.push(systemRoute.route[sr]);
        }

        if (jumps >= 10) {
            enough = true;
        }
    }

    return posArr;
}

this.$checkOtherOXP = function () {
    // Check OXPs main files (look into the OXZs) and set associate flags

    // Examples:
    // this.litfVars.oxp.fuelStation = worldScripts["FuelStation-Setup"] ? 1 : 0;
    // this.litfVars.oxp.hoopyCasino = worldScripts["hoopy_casino"] ? 1 : 0;

    // _co.$log("[LITF] checkOtherOXP = " + JSON.stringify(this.litfVars.oxp));
}
