/* eslint-disable semi, no-multi-spaces, quotes, indent, no-tabs, yoda */
/* global worldScripts, system, mission, player, clock, randomName, setScreenBackground  */

"use strict";

this.name        = "LITF_BBS";
this.author      = "BeeTLe BeTHLeHeM";
this.copyright   = "2018 BeeTLe BeTHLeHeM";
this.description = "Code for BBS management - message list, mission creation, mission details";
this.version     = "0.10.0";
this.licence     = "CC BY-NC-SA 4.0";

// Feedback requirements defaults

// Currently not used
this.minFeedbackDefault = -10; // Default minimum feedback required for missions (except GalShady ones)
this.maxFeedbackDefault = 24; // Default maximum feedback required for missions (only GalShady ones)

this.halfAdvanceMinFeedbackDefault = 10; // Default minimum feedback required for obtaining half advance reward
this.fullAdvanceMinFeedbackDefault = 50; // Default minimum feedback required for obtaining full advance reward
this.moreMoneyMinFeedbackDefault   = 25; // Default minimum feedback required for obtaining more reward (10-25% more)

this.bbsData = null;

var _litf    = null;
var _co      = null;
var _md      = null;
var _mi      = null;

// Local var reference for callback methods

var $display = this.$display;
var $executeCharityActions = this.$executeCharityActions;
var $executeMissionActions = this.$executeMissionActions;
var $executePlayerWaitingActions = this.$executePlayerWaitingActions;

this.$run = function () {
    _co.$log("[LITF_BBS] run");

    _litf = worldScripts.LITF;

    this.bbsData = _litf.litfVars.bbsData;

    _co   = worldScripts.LITF_Common;
    _md   = worldScripts.LITF_MissionData;
    _mi   = worldScripts.LITF_Missions;

    // Load the BBS list
    this.$init();

    // Display the BBS page
    this.$display();
}

this.$init = function () {
    _co.$log("[LITF_BBS] init");

    // What to do with this?
    if (_litf.litfVars.enterBBSFlag === true) {
        _litf.litfVars.enterBBSFlag = false;
    }
}

this.$createBBSItems = function () {
    _co.$log("[LITF_BBS] createBBSItems");

    var bbsData = _litf.litfVars.bbsData;

    bbsData.bbsItemsArr = [];
    bbsData.checkDuplicatesArr = [];

    // From the system government we get the active groups
    var stationData = _litf.litfVars.stationParams;
    var activeGroups = _mi.groupsByGov[stationData.government];

    // Cycle the active groups and eventually set some mission each group
    var totGroupMissions = 5 + _co.$roll(0, activeGroups.length / 2);
    for (var g = 0; g < totGroupMissions; g++) {
        var mObj = _mi.$generateMission(activeGroups);
        if (mObj != null) {
            mObj.missionId = _co.$getGeneralId();
            bbsData.bbsItemsArr.push(mObj);
        }
    }

    // Waiting mission generation (dummy)
    var totWaitingMissions = _co.$roll(1, 4);
    for (var w = 0; w < totWaitingMissions; w++) {
        var wObj = _mi.$generateRandomItem(_md.waitingStore);
        wObj.missionId = _co.$getGeneralId();
        bbsData.bbsItemsArr.push(wObj);
    }

    // Government specific messages
    var totGovItems = _co.$roll(3, 6);
    for (var go = 0; go < totGovItems; go++) {
        var gObj = _mi.$generateGovernmentItem();
        gObj.missionId = _co.$getGeneralId();
        bbsData.bbsItemsArr.push(gObj);
    }

    // Advertising messages generation
    var totAdItems = activeGroups.length + _co.$roll(0, 4);
    for (var a = 0; a < totAdItems; a++) {
        var aObj = _mi.$generateRandomItem(_md.adStore);
        aObj.missionId = _co.$getGeneralId();
        bbsData.bbsItemsArr.push(aObj);
    }

    // Charity request messages generation
    var totCharityItems = _co.$roll(1, 1);
    for (var c = 0; c < totCharityItems; c++) {
        var cObj = _mi.$generateRandomItem(_md.charityStore);
        cObj.missionId = _co.$getGeneralId();
        bbsData.bbsItemsArr.push(cObj);
    }

    // Debug //
    if (_litf.litfVars.config.debubg === true) {
        _co.$log("generate debug items");
        var dObj = null;
        for (var d = 0; d < 2; d++) {
            // dObj = _mi.$generateMission(["debug"], 1);
            // bbsData.bbsItemsArr.push(dObj);

            // dObj = _mi.$generateMission(["debug"], 2);
            // bbsData.bbsItemsArr.push(dObj);

            // dObj = _mi.$generateMission(["debug"], 3);
            // bbsData.bbsItemsArr.push(dObj);

            dObj = _mi.$generateMission(["debug"], 4);
            if (dObj !== null) {
                bbsData.bbsItemsArr.push(dObj);
            }
        }
    }
    // Debug //

    _co.$log("generate player waiting items")

    // Check if there's a mission to complete in this system - create BBS message accordingly.
    var activeMissions = _litf.litfCommander.activeMissions;
    _co.$log("activeMissions length = " + activeMissions.length);

    if (activeMissions.length > 0) {
        for (var am = 0; am < activeMissions.length; am++) {
            var amItem = activeMissions[am];

            if (this.$checkActiveMissionHere(amItem) === true) {
                var pwObj = _mi.$generatePlayerWaitingMission(amItem);

                bbsData.bbsItemsArr.push(pwObj);
                _co.$log("pwObj = " + JSON.stringify(pwObj));
            }
        }
    }

    _co.$log("shuffleArray");

    // Shuffle the list
    bbsData.bbsItemsArr = _co.$shuffleArray(bbsData.bbsItemsArr);
}

this.$checkActiveMissionHere = function (amItem) {
    _co.$log("[LITF_BBS] checkActiveMissionHere");
    _co.$log("amItem = " + JSON.stringify(amItem));

    var cTask = this.$getMissionTask(amItem, amItem.currentTask);
    _co.$log("cTask = " + JSON.stringify(cTask));

    var systems = cTask.info.systems;
    var amHere = false;

    for (var sy = 0; sy < systems.length; sy++) {
        if (this.$isSystems(systems) === true) {
            amHere = true;
            break;
        }
    }

    return amHere;
}

// Check if the player is in one of the systems of the input array
this.$isSystems = function (systemArr) {
    _co.$log("[LITF_BBS] isSystem");

    var isSystems = false;

    for (var s = 0; s < systemArr.length; s++) {
        // System exists and its not already "completed" (visit + talk)

        _co.$log("system.ID = " + system.ID + " systemArr[" + s + "] = " + JSON.stringify(systemArr[s]));

        if (!systemArr[s].hidden || systemArr[s].hidden === false) {
            if (systemArr[s].id === system.ID) {
                isSystems = true;
            }
        }
    }

    return isSystems;
}

this.$display = function () {
    var bbsData = _litf.litfVars.bbsData;

    _co.$log("[LITF_BBS] display");
    _co.$log("bbsMode = " + bbsData.bbsMode);

    var displayText = "";
    var opts = null;
    var curChoices = null;

    if (bbsData.bbsMode === 0) {
        // BBS message list
        displayText = "(" + (bbsData.selectedItem + 1) + " / " + bbsData.bbsItemsArr.length + ")\n\n";

        this.$setPageListEdges();

        var lastItemIdx = bbsData.firstItemIdx + bbsData.rowsSize;
        if (lastItemIdx > bbsData.bbsItemsArr.length) {
            lastItemIdx = bbsData.bbsItemsArr.length;
        }

        for (var r = bbsData.firstItemIdx; r < lastItemIdx; r++) {
            var iObj = bbsData.bbsItemsArr[r];

            if (r === bbsData.selectedItem) {
                displayText += "> ";
            } else {
                displayText += "    ";
            }

            var iTitle = iObj.title;
            if (iTitle.length > 70) {
                iTitle = iTitle.substring(0, 70) + "...";
            }

            displayText += iTitle + "\n";
        }

        curChoices = this.$definePageListChoices();

        opts = {
            title: system.name + " Bulletin Board",
            exitScreen: "GUI_SCREEN_INTERFACES",
            message: displayText,
            choices: curChoices,
            initialChoicesKey: bbsData.lastChoice
        };

        mission.runScreen(opts, this.$updateMissionList);
    } else if (bbsData.bbsMode === 1) {
        // BBS item details
        var selItemObj = bbsData.selectedItemObj;

        displayText += "// " + selItemObj.title + "\n\n";

        _co.$log("mission details: " + JSON.stringify(selItemObj));

        if (selItemObj.groupId === 97) {
            // Player waiting message item

            var stepObj = this.$getCurrentStep(selItemObj);
            displayText += stepObj.description + "\n";

            curChoices = stepObj.choice;
        } else {
            displayText += selItemObj.description + "\n";

            if (selItemObj.showCredits === true) {
                displayText += "\nYOUR CREDITS: " + player.credits;
            } else if (selItemObj.choices !== "hangup") {
                var etaTime = _co.$formatTime(selItemObj.timeAllowed, false);
                displayText += "\nDEADLINE: " + etaTime + ".";
            }

            if (selItemObj.choices !== "hangup") {
                for (var t = 0; t < selItemObj.tasks.length; t++) {
                    var task = selItemObj.tasks[t];
                    if (!task.hideSystemData) {
                        for (var s = 0; s < task.info.systems.length; s++) {
                            var sItem = task.info.systems[s];
                            if (sItem.distance > 0) {
                                displayText += "\nSYSTEM DATA: " + sItem.name + " (distance: " + sItem.distance + " ly)";
                            }
                        }
                    }
                }

                _co.$log("response = " + selItemObj.response);
                if (selItemObj.response && selItemObj.response !== null) {
                    displayText += "\n\n> " + selItemObj.response;
                }
            }

            curChoices = this.$getChoices(selItemObj.choices);
        }

        opts = {
            title: system.name + " Bulletin Board",
            exitScreen: "GUI_SCREEN_INTERFACES",
            message: displayText,
            choices: curChoices
        };

        mission.runScreen(opts, this.$updateMissionDetails);

        // Frontier: Elite face backgrounds - disabled because I am afraid are copyrighted.
        if (_litf.litfVars.config.disableMissionBackground && _litf.litfVars.config.disableMissionBackground === false) {
            if (selItemObj.faceBackground) {
                setScreenBackground(selItemObj.faceBackground);
            }
        }
    }
}

this.$getCurrentStep = function (pwObj) {
    _co.$log("[LITF_BBS] getCurrentStep");

    var steps = pwObj.steps;
    var currentStep = pwObj.currentStep;
    var sObj = {};

    for (var s = 0; s < steps.length; s++) {
        var sItem = steps[s];
        if (sItem.index === currentStep) {
            sObj = sItem;
            break;
        }
    }

    _co.$log("step[" + currentStep + "] = " + JSON.stringify(sObj));

    return sObj;
}

this.$getChoices = function (cLabel) {
    var choices = null;

    if (cLabel === "mission") {
        choices = _md.missionChoices;
    } else if (cLabel === "transport") {
        choices = _md.transportChoices;
    } else if (cLabel === "cargo") {
        choices = _md.cargoChoices;
    } else if (cLabel === "hangup") {
        choices = _md.hangupChoices;
    } else if (cLabel === "charity") {
        choices = _md.charityChoices;
    } else {
        choices = _md.hangupChoices;
    }

    return choices;
}

this.$setPageListEdges = function () {
    var bbsData = _litf.litfVars.bbsData;

    if (bbsData.selectedItem < bbsData.firstItemIdx) {
        bbsData.firstItemIdx = bbsData.selectedItem;
    }

    if (bbsData.selectedItem > (bbsData.firstItemIdx + bbsData.rowsSize - 1)) {
        bbsData.firstItemIdx = (bbsData.selectedItem - bbsData.rowsSize + 1);
    }
}

this.$updateMissionDetails = function (choice) {
    _co.$log("[LITF_BBS] updateMissionDetails");

    var bbsData = _litf.litfVars.bbsData;

    var cLabel = bbsData.selectedItemObj.choices;

    _co.$log("choice = " + choice);

    if (!choice) {
        _co.$log("NULL choice? What's happened there?");
        return;
    } else if (choice.indexOf("_QUIT") > -1) {
        bbsData.bbsMode = 0;
        $display();
    } else if (cLabel === "mission") {
        $executeMissionActions(choice);
        $display();
    } else if (cLabel === "transport") {
        $executeMissionActions(choice);
        $display();
    } else if (cLabel === "cargo") {
        $executeMissionActions(choice);
        $display();
    } else if (cLabel === "charity") {
        $executeCharityActions(choice);
        $display();
    } else if (cLabel === "waiting") {
        $executePlayerWaitingActions(choice);
        $display();
    }
}

this.$updateMissionList = function (choice) {
    var bbsData = _litf.litfVars.bbsData;

    if (!choice) {
        _co.$log("NULL choice? What's happened there?");
        return;
    } else if (choice === "99_DISCONNECT") {
        bbsData.firstItemIdx = 0;
        bbsData.selectedItem = 0;
        _litf.$LITFinterface();
    } else {
        if (choice === "01_PREV_ITEM") {
            if (bbsData.selectedItem > 0) {
                bbsData.selectedItem = bbsData.selectedItem - 1;
            }
        } else if (choice === "02_NEXT_ITEM") {
            if (bbsData.selectedItem < bbsData.bbsItemsArr.length - 1) {
                bbsData.selectedItem = bbsData.selectedItem + 1;
            }
        } else if (choice === "03_SELECT_ITEM") {
            // Open the details screen

            bbsData.selectedItemObj = bbsData.bbsItemsArr[bbsData.selectedItem];
            bbsData.selectedItemObj.response = null;

            bbsData.bbsMode = 1;
        }

        bbsData.lastChoice = choice;

        $display();
    }
}

this.$definePageListChoices = function () {
    _co.$log("[LITF_BBS] definePageListChoices");

    var bbsData = _litf.litfVars.bbsData;

    var choices = {};

    if (bbsData.selectedItem > 0) {
        choices["01_PREV_ITEM"] = { text: "Select previous item", color: "yellowColor" };
    } else {
        choices["01_PREV_ITEM"] = { text: "Select previous item", color: "darkGrayColor", unselectable: true };
    }

    if (bbsData.selectedItem < bbsData.bbsItemsArr.length - 1) {
        choices["02_NEXT_ITEM"] = { text: "Select next item", color: "yellowColor" };
    } else {
        choices["02_NEXT_ITEM"] = { text: "Select next item", color: "darkGrayColor", unselectable: true };
    }

    // Check mission object to see if it allows for a detail screen

    var sObj = bbsData.bbsItemsArr[bbsData.selectedItem];
    _co.$log("selectedItem = " + bbsData.selectedItem + " sObj = " + JSON.stringify(sObj));

    if (sObj.choices) {
        choices["03_SELECT_ITEM"] = { text: "Contact Sender", color: "yellowColor" };
    } else {
        choices["03_SELECT_ITEM"] = { text: "Contact Sender", color: "darkGrayColor", unselectable: true };
    }

    choices["99_DISCONNECT"] = { text: "Disconnect from BBS", color: "yellowColor" };

    return choices;
}

this.$getParentMissionObject = function (pwObj) {
    var pmObj = null;

    for (var am = 0; am < _litf.litfCommander.activeMissions.length; am++) {
        var amItem = _litf.litfCommander.activeMissions[am];

        if (amItem.missionId === pwObj.parentMissionId) {
            pmObj = amItem;
            break;
        }
    }

    return pmObj;
}

this.$executePlayerWaitingActions = function (choice) {
    _co.$log("[LITF_BBS] executePlayerWaitingActions");

    var bbsData = _litf.litfVars.bbsData;

    var pwObj = bbsData.selectedItemObj; // Player wwaiting BBS item

    var pmObj = this.$getParentMissionObject(pwObj); // Original active mission item
    _co.$log("pmObj = " + JSON.stringify(pmObj));

    var currentTask = this.$getMissionTask(pmObj, pmObj.currentTask);
    var nextTask = this.$getMissionTask(pmObj, pmObj.currentTask + 1);
    _co.$log("currentTask = " + JSON.stringify(currentTask));

    var start = -1;
    var destination = -1;
    var arrivalTime = -1;
    var risk = -1;
    var parcel = null;
    //

    if (choice.indexOf("_GOTO_") > -1) {
        var choiceSplit = choice.split("_");
        pwObj.currentStep = parseInt(choiceSplit[2]);
        _co.$log("go to step = " + pwObj.currentStep);
    } else if (choice.indexOf("_NEXTTASK") > -1) {
        var advance = true;

        // Parcel Contracts
        if (currentTask.parcel) {
            parcel = "(BBS) " + currentTask.parcel;

            var newParcel = false;

            start = currentTask.info.systems[0].id;
            destination = nextTask.info.systems[0].id;

            arrivalTime = clock.seconds + pmObj.timeAllowed + 5;

            risk = 0;
            if (pmObj.risk) { risk = pmObj.risk; }

            newParcel = player.ship.addParcel(parcel, start, destination, arrivalTime, 0, 0, risk);
            _co.$log("newParcel = " + newParcel);

            advance = newParcel;
        }

        if (currentTask.passengers) {
            var passengers = currentTask.passengers; // Number of passengers
            _co.$log("passengerCapacity = " + player.ship.passengerCapacity + " passengerCount = " + player.ship.passengerCount);

            var availableCabins = player.ship.passengerCapacity - player.ship.passengerCount;
            _co.$log("availableCabins = " + availableCabins + " for Passengers = " + passengers);

            if (availableCabins < passengers) {
                var choiceStr = pwObj.steps[pwObj.currentStep].choices[choice];
                if (passengers === 1) {
                    pwObj.response = choiceStr + "\nI'm sorry, but we can't leave! You haven't an available cabin for me!"
                } else {
                    pwObj.response = choiceStr + "\nI'm sorry, but we can't leave! You haven't enough available cabins for all of us!"
                }

                advance = false;
            } else {
                // Create a contract for every passenger

                if (!pmObj.passengerList) { pmObj.passengerList = []; }

                start = currentTask.info.systems[0].id;
                destination = nextTask.info.systems[0].id;
                // _co.$log("transport from [" + currentTask.info.systems[0].name + "] to [" + nextTask.info.systems[0].name + "]");

                arrivalTime = clock.seconds + pmObj.timeAllowed + 5;

                risk = 0;
                if (pmObj.risk) { risk = pmObj.risk; }

                for (var p = 0; p < passengers; p++) {
                    if (p < currentTask.info.names.length) {
                        var pName = "(BBS) " + currentTask.info.names[p];
                        pmObj.passengerList.push(pName);

                        var newPassenger = player.ship.addPassenger(pName, start, destination, arrivalTime, 0, 0, risk);
                        _co.$log("addPassenger(" + pName + ", " + start + ", " + destination + ", " + arrivalTime + ", 0, " + risk + ") == " + newPassenger);
                    }
                }
            }
        }

        if (currentTask.typeId === 5) {
            // Cargo mission
            if (player.ship.cargoSpaceUsed > 0) {
                pwObj.response = choiceStr + "\nI'm sorry, but we need all your ship space for this shipment. Empty your cargo before accepting the job."
                advance = false;
            } else {
                var cargoGoods = currentTask.info.goods[0];
                _co.$log("Cargo mission for " + cargoGoods);

                player.ship.useSpecialCargo("(BBS) A shipment of " + cargoGoods);
            }
        }

        //

        if (advance === true) {
            this.$advanceActiveMissionTask(pwObj.parentMissionId);

            // Delete player waiting item from BBS
            this.$deleteBBSItem(pwObj.missionId);

            player.consoleMessage("Mission advanced to next task.");

            bbsData.bbsMode = 0;
        }

        $display();
    } else if (choice.indexOf("_COMPLETE") > -1) {
        if (currentTask.typeId < 4) {
            // Remove parcel contract

            parcel = null;
            if (pmObj.parcel) {
                parcel = "(BBS) " + pmObj.parcel;
            } else {
                for (var t = 0; t < pmObj.tasks.length; t++) {
                    var task = pmObj.tasks[t];
                    if (task.parcel) {
                        parcel = "(BBS) " + task.parcel;
                    }
                }
            }

            player.ship.removeParcel(parcel);
            _co.$log("removing parcel: " + parcel);
        } else if (currentTask.typeId === 4) {
            // Remove every passenger contract

            if (pmObj.passengerList) {
                for (var pa = 0; pa < pmObj.passengerList.length; pa++) {
                    player.ship.removePassenger(pmObj.passengerList[pa]);
                    _co.$log("removePassenger(" + pmObj.passengerList[pa] + ")");
                }
            }
        } else if (currentTask.typeId === 5) {
            // Cargo mission

            player.ship.removeAllCargo();
            _co.$log("removing special cargo (I hope)");
        }

        // Mission completed
        var consText = "Mission complete.";

        // Get credits award
        if (pwObj.reward > 0) {
            player.credits = player.credits + pwObj.reward;
            consText += " " + pwObj.reward + "cr received.";
        }

        // Get feedback award
        if (pmObj.groupId === 3) {
            _co.$setPlayerFeedback(-pwObj.feedbackSuccess);
        } else {
            _co.$setPlayerFeedback(pwObj.feedbackSuccess);
        }

        // Delete active mission
        this.$deleteActiveMission(pwObj.parentMissionId);

        // Delete player waiting item from BBS
        this.$deleteBBSItem(pwObj.missionId);

        _co.$updateStatistics("missionCompleted", pmObj.groupId, 1);
        _co.$updateStatistics("feedbackGained", pmObj.groupId, pwObj.feedbackSuccess);

        player.consoleMessage(consText);

        bbsData.bbsMode = 0;
        $display();
    }
}

this.$advanceActiveMissionTask = function (advanceMissionId) {
    _co.$log("[LITF_BBS] deleteActiveMission");

    var updated = false;

    for (var am = 0; am < _litf.litfCommander.activeMissions.length; am++) {
        var amItem = _litf.litfCommander.activeMissions[am];

        _co.$log("[" + am + "] item.missionId[" + amItem.missionId + "] advanceMissionId = " + advanceMissionId);

        if (amItem.missionId === advanceMissionId) {
            amItem.currentTask = amItem.currentTask + 1;
            updated = true;
            break;
        }
    }

    _co.$log("updated = " + updated);
}

this.$deleteActiveMission = function (deleteMissionId) {
    _co.$log("[LITF_BBS] deleteActiveMission");

    var ret = {
        groupId: -1,
        deleted: false,
        removedPassengers: 0,
        deadPassengers: 0,
        cargo: null,
        parcel: null,
        feedback: {}
    }

    var removedPassengers = 0;
    var deadPassengers = 0;

    for (var am = 0; am < _litf.litfCommander.activeMissions.length; am++) {
        var amItem = _litf.litfCommander.activeMissions[am];

        _co.$log("[" + am + "] item.missionId[" + amItem.missionId + "] deleteMissionId = " + deleteMissionId);

        if (amItem.tasks[0].typeId === 5) {
            // Cargo contract
            ret.cargo = amItem.tasks[0].info.goods[0];
        }

        if (amItem.tasks[0].typeId < 4) {
            // Parcel contract
            if (amItem.parcel) {
                ret.parcel = amItem.parcel;
            } else {
                for (var t = 0; t < amItem.tasks.length; t++) {
                    var task = amItem.tasks[t];
                    if (task.parcel) {
                        ret.parcel = task.parcel;
                    }
                }
            }
        }

        if (amItem.missionId === deleteMissionId) {
            // Remove passengers, if any
            if (amItem.passengerList) {
                if (amItem.failureDead === true) {
                    deadPassengers = deadPassengers + amItem.passengerList.length;
                } else {
                    removedPassengers = removedPassengers + amItem.passengerList.length;
                }

                for (var pa = 0; pa < amItem.passengerList.length; pa++) {
                    player.ship.removePassenger(amItem.passengerList[pa]);
                    _co.$log("removePassenger(" + amItem.passengerList[pa] + ")");
                }

                ret.groupId = amItem.groupId;

                ret.feedback.gained = amItem.feedbackSuccess;
                ret.feedback.lost = amItem.feedbackFailure;
            }

            _litf.litfCommander.activeMissions.splice(am, 1);
            ret.deleted = true;
            break;
        }
    }

    ret.removedPassengers = removedPassengers;
    ret.deadPassengers = deadPassengers;

    _co.$log("ret = " + JSON.stringify(ret));

    return ret;
}

this.$executeMissionActions = function (choice) {
    _co.$log("[LITF_BBS] executeMissionActions");

    var bbsData = _litf.litfVars.bbsData;

    var mObj = bbsData.selectedItemObj;
    var currentTask = this.$getMissionTask(mObj, mObj.currentTask);

    var choiceStr = this.$getChoices(mObj.choices)[choice];
    var pFeedback = _litf.litfCommander.feedback;
    var minFeedback = 0;

    var start = -1;
    var destination = -1;
    var arrivalTime = -1;
    var risk = -1;

    if (choice === "01_OK") {
        // "Ok - agreed."

        var agree = true;

        // Parcel Contracts
        if (mObj.parcel) {
            var parcel = "(BBS) " + mObj.parcel;

            var newParcel = false;

            start = mObj.startingSystem.id;
            destination = currentTask.info.systems[0].id;

            arrivalTime = clock.seconds + mObj.timeAllowed + 5;

            risk = 0;
            if (mObj.risk) { risk = mObj.risk; }

            newParcel = player.ship.addParcel(parcel, start, destination, arrivalTime, 0, 0, risk);
            _co.$log("newParcel = " + newParcel);

            agree = newParcel;
        }

        // Passengers contracts
        if (mObj.passengers) {
            var passengers = mObj.passengers; // Number of passengers

            // _co.$log("passengerCapacity = " + player.ship.passengerCapacity + " passengerCount = " + player.ship.passengerCount);

            var availableCabins = player.ship.passengerCapacity - player.ship.passengerCount;
            // _co.$log("availableCabins = " + availableCabins + " for Passengers = " + passengers);

            if (availableCabins < passengers) {
                if (passengers === 1) {
                    if (mObj.firstPassenger && mObj.firstPassenger === 0) {
                        mObj.response = choiceStr + "\nI'm sorry, but we can't leave! You haven't an available cabin for me!"
                    } else {
                        mObj.response = choiceStr + "\nI'm sorry, but we can't leave! You haven't an available cabin for the passenger!"
                    }
                } else {
                    if (mObj.firstPassenger && mObj.firstPassenger === 0) {
                        mObj.response = choiceStr + "\nI'm sorry, but we can't leave! You haven't enough available cabins for all of us!"
                    } else {
                        mObj.response = choiceStr + "\nI'm sorry, but we can't leave! You haven't an available cabin for all the passengers!"
                    }
                }
                agree = false;
            } else {
                // Create a contract for every passenger

                if (!mObj.passengerList) { mObj.passengerList = []; }

                start = mObj.startingSystem.id;
                destination = currentTask.info.systems[0].id;

                _co.$log("transport from [" + mObj.startingSystem.name + "] to [" + currentTask.info.systems[0].name + "]");

                arrivalTime = clock.seconds + mObj.timeAllowed + 5;

                risk = 0;
                if (mObj.risk) { risk = mObj.risk; }

                var newPassenger = false;

                if (mObj.firstPassenger) {
                    var passenger1 = null;
                    if (mObj.firstPassenger === 0) {
                        passenger1 = mObj.contractor;
                    } else if (mObj.firstPassenger > 0) {
                        var pTask = this.$getMissionTask(mObj, mObj.firstPassenger);
                        passenger1 = pTask.info.names[0];
                    }
                    newPassenger = player.ship.addPassenger(passenger1, start, destination, arrivalTime, 0, 0, risk);
                    _co.$log("addPassenger(" + passenger1 + ", " + start + ", " + destination + ", " + arrivalTime + ", 0, " + risk + ") == " + newPassenger);
                    passengers = passengers - 1;
                }

                for (var p = 0; p < passengers; p++) {
                    var pName = "(BBS) " + randomName() + " " + randomName();
                    mObj.passengerList.push(pName);

                    newPassenger = player.ship.addPassenger(pName, start, destination, arrivalTime, 0, 0, risk);
                    _co.$log("addPassenger(" + mObj.contractor + ", " + start + ", " + destination + ", " + arrivalTime + ", 0, " + risk + ") == " + newPassenger);
                }
            }
        } else if (currentTask.typeId === 4) {
            var pCapacity = player.ship.passengerCapacity
            if (pCapacity === 0) {
                mObj.response = choiceStr + "\nI'm sorry, but you haven't a single cabin on your ship!"
                agree = false;
            }
        }

        // Cargo contracts
        if (currentTask.typeId === 5) {
            if (player.ship.cargoSpaceUsed > 0) {
                mObj.response = choiceStr + "\nI'm sorry, but we need all your ship space for this shipment. Empty your cargo before accepting the job."
                agree = false;
            } else {
                var cargoGoods = currentTask.info.goods[0];
                _co.$log("Cargo mission for " + cargoGoods);

                player.ship.useSpecialCargo("(BBS) A shipment of " + cargoGoods);
            }
        }

        // Check max active missions limit
        if (agree === true) {
            var maxActiveMissions = parseInt(Math.abs(pFeedback) / 25) + 1;
            if (_litf.litfCommander.activeMissions.length === maxActiveMissions) {
                mObj.response = choiceStr + "\nI'm sorry, your feedback doesn't allow you to accept more missions. Increasing the feedback you'll be able to accept more missions at the same time."
                agree = false;
            }
            _co.$log("active missions: " + _litf.litfCommander.activeMissions.length + " max: " + maxActiveMissions + " agree = " + agree);
        }

        //

        if (agree === true) {
            var advance = 0;

            // Accept mission
            if (mObj.rewardAdvanceObtained !== null) {
                if (mObj.rewardAdvanceObtained === "half") {
                    advance = mObj.reward / 2;
                    player.credits = player.credits + advance;
                    mObj.reward = mObj.reward / 2;
                } else if (mObj.rewardAdvanceObtained === "full") {
                    advance = mObj.reward;
                    player.credits = player.credits + advance;
                    mObj.reward = 0;
                }
            }

            // define reputation success and failure score
            mObj.feedbackSuccess = this.$feedbackSuccessScore(mObj);
            mObj.feedbackFailure = this.$feedbackFailureScore(mObj);

            //

            mObj.startTime = clock.seconds;

            _litf.litfCommander.activeMissions.push(mObj);

            this.$deleteBBSItem(mObj.missionId);

            _co.$updateStatistics("missionAccepted", mObj.groupId, 1);

            player.consoleMessage("Mission has been accepted.");
            if (advance > 0) {
                player.consoleMessage("Received " + advance + "cr as advance.");
            }

            bbsData.bbsMode = 0;
        }

        $display();
    } else if (choice === "02_HOWMANY") {
        // "How many of you are there?"
        var totPassengers = this.$howManyPassengers(mObj);
        if (totPassengers === 1) {
            mObj.response = choiceStr + "\nOnly one person.";
        } else if (totPassengers > 1) {
            mObj.response = choiceStr + "\nA group of " + totPassengers + " persons.";
        }
    } else if (choice === "03_MONEY") {
        // "Why so much money?"
        mObj.response = choiceStr + "\n" + mObj.responses.money;
    } else if (choice === "04_PROBLEMS") {
        // "Will there be any problems?"
        mObj.response = choiceStr + "\n" + mObj.responses.problems;
    } else if (choice === "05_PERMIT") {
        // "Do I need a permit, and if so can I have one?"
        mObj.response = choiceStr + "\nDon't be silly - you don't need a permit.";
    } else if (choice === "05_UNAWARE") {
        // "Do the recipient will know of my arrival?"
        if (currentTask.unaware === false) {
            mObj.response = choiceStr + "\n" + mObj.responses.unaware[0];
        } else {
            mObj.response = choiceStr + "\n" + mObj.responses.unaware[1];
        }
    } else if (choice === "06_MOREMONEY") {
        // "I want more money."
        minFeedback = mObj.moreMoneyMinFeedback ? mObj.moreMoneyMinFeedback : this.moreMoneyMinFeedbackDefault;
        if (pFeedback < minFeedback) {
            mObj.response = choiceStr + "\n" + mObj.reward + "cr is all I can pay.";
        } else if (mObj.moreMoneyObtained === false) {
            var percentMore = (_co.$roll(0, 3) * 5) + 10;
            var newReward = mObj.reward + (mObj.reward / 100 * percentMore);

            mObj.reward = newReward;
            mObj.response = choiceStr + "\nOk. Considering your feedback I can increase the reward to " + mObj.reward + " credits.";
            mObj.moreMoneyObtained = true;
        } else {
            mObj.response = choiceStr + "\nWe've agreed on payment of " + mObj.reward + " credits.";
        }
    } else if (choice === "07_HALFADVANCE") {
        // "I want half the money now."
        minFeedback = mObj.halfAdvanceMinFeedback ? mObj.halfAdvanceMinFeedback : this.halfAdvanceMinFeedbackDefault;
        if (pFeedback < minFeedback) {
            mObj.response = choiceStr + "\nWhat sort of fool do you take me for?";
        } else if (mObj.rewardAdvanceObtained === null) {
            mObj.response = choiceStr + "\nOk. I'll pay half once you agree, and half on arrival.";
            mObj.rewardAdvanceObtained = "half";
        } else {
            mObj.response = choiceStr + "\nWe've agreed on payment.";
        }
    } else if (choice === "08_FULLADVANCE") {
        // "I want all the money now."
        minFeedback = mObj.fullAdvanceMinFeedback ? mObj.fullAdvanceMinFeedback : this.fullAdvanceMinFeedbackDefault;
        if (pFeedback < minFeedback) {
            mObj.response = choiceStr + "\nWhat sort of fool do you take me for?";
        } else if (mObj.rewardAdvanceObtained === null) {
            mObj.response = choiceStr + "\nOk. I'll pay the full reward once you agree.";
            mObj.rewardAdvanceObtained = "full";
        } else {
            mObj.response = choiceStr + "\nWe've agreed on payment.";
        }
    }
}

this.$howManyPassengers = function (mObj) {
    _co.$log("[LITF_BBS] howManyPassengers");
    var totalPassengers = 0;

    if (mObj.passengers) {
        totalPassengers = totalPassengers + mObj.passengers;
    }

    for (var ta = 0; ta < mObj.tasks.length; ta++) {
        var task = mObj.tasks[ta];
        if (task.passengers) {
            totalPassengers = totalPassengers + task.passengers;
        }
    }

    _co.$log("totalPassengers = " + totalPassengers);
    return totalPassengers;
}

this.$deleteBBSItem = function (itemId) {
    var deleted = false;

    var bbsData = _litf.litfVars.bbsData;

    for (var i = 0; i < bbsData.bbsItemsArr.length; i++) {
        var item = bbsData.bbsItemsArr[i];

        if (item.missionId === itemId) {
            bbsData.bbsItemsArr.splice(i, 1);
            deleted = true;
            break;
        }
    }

    if (deleted === true) {
        while (bbsData.selectedItem >= bbsData.bbsItemsArr.length) {
            bbsData.selectedItem = bbsData.selectedItem - 1;
        }
    }
}

this.$executeCharityActions = function (choice) {
    _co.$log("[LITF_BBS] executeCharityActions");

    if (choice === "01_DONATE01") {
        this.$actionDonate(choice, 0.1);
    } else if (choice === "02_DONATE1") {
        this.$actionDonate(choice, 1);
    } else if (choice === "03_DONATE10") {
        this.$actionDonate(choice, 10);
    } else if (choice === "04_DONATE100") {
        this.$actionDonate(choice, 100);
    } else if (choice === "05_DONATE1000") {
        this.$actionDonate(choice, 1000);
    } else if (choice === "06_DONATE10000") {
        this.$actionDonate(choice, 10000);
    }
}

this.$actionDonate = function (choice, amount) {
    _co.$log("[LITF_BBS] actionDonate");

    var bbsData = _litf.litfVars.bbsData;

    var choiceStr = this.$getChoices(bbsData.selectedItemObj.choices)[choice];

    if (player.credits < amount) {
        bbsData.selectedItemObj.response = choiceStr + "\nYou don't have enough cash.";
    } else {
        player.credits = player.credits - amount;
        bbsData.selectedItemObj.response = choiceStr + "\nThank you. All donations are gratefully received.";

        // Feedback reward

        if (amount === 0.1) {
            // No feedback reward
        } else if (amount === 1) {
            if (_co.$roll(1, 100) < 5) {
                _co.$setPlayerFeedback(1);
            }
        } else if (amount === 10) {
            if (_co.$roll(1, 100) < 20) {
                _co.$setPlayerFeedback(1);
            }
        } else if (amount === 100) {
            _co.$setPlayerFeedback(1);
        } else if (amount === 1000) {
            _co.$setPlayerFeedback(5);
        } else if (amount === 10000) {
            _co.$setPlayerFeedback(10);
        }
    }
}

this.$feedbackSuccessScore = function (mObj) {
    _co.$log("[LITF_BBS] feedbackSuccessScore");

    var score = 2;

    if (mObj.local === false) {
        if (mObj.moreMoneyObtained === false) {
            score = score + 1;
        }

        if (mObj.rewardAdvanceObtained === null) {
            score = score + 1;
        }
    }

    return score;
}

this.$feedbackFailureScore = function (mObj) {
    _co.$log("[LITF_BBS] feedbackFailureScore");

    var score = 2;

    if (mObj.local === false) {
        if (mObj.moreMoneyObtained === true) {
            score = score + 2;
        }

        if (mObj.rewardAdvanceObtained === "half") {
            score = score + 1;
        } else if (mObj.rewardAdvanceObtained === "full") {
            score = score + 2;
        }
    }

    return score;
}

this.$getMissionTask = function (mObj, taskIndex) {
    _co.$log("[LITF_BBS] getCurrentTask");

    var tasks = mObj.tasks;
    var tObj = {};

    for (var t = 0; t < tasks.length; t++) {
        var tItem = tasks[t];
        if (tItem.index === taskIndex) {
            tObj = tItem;
            break;
        }
    }

    _co.$log("task[" + taskIndex + "] = " + JSON.stringify(tObj));

    return tObj;
}
