/* eslint-disable semi, no-multi-spaces, quotes, indent, no-tabs, yoda */
/* global worldScripts, player, log, system, clock, galaxyNumber */

"use strict";

this.name        = "LITF_Common";
this.author      = "BeeTLe BeTHLeHeM";
this.copyright   = "2018 BeeTLe BeTHLeHeM";
this.description = "Library of common methods";
this.version     = "0.10.0";
this.licence     = "CC BY-NC-SA 4.0";

// Groups labels

this.groupsLabels = ["GalCop", "GalBook", "GalChurch", "GalShady", "GalMedical", "GalCivic", "GalTourism", "GalShopping", "GalNature", "GalCulture", "GalGovernment", "GalDebug"];

// Sub-commodity and associated commodity (for reference price)

this.commodityReference = {
	"food": [ "Grain", "Generic Foods", "Food Dispensers", "Medicines", "Farm Animals", "Colture Plants", "Junk Foods" ],
	"textiles": [ "Textiles" ],
	"machinery": [ "Factory Equipment", "Mining Equipment", "Robo-Servants", "Robo-Workers", "Robo-Fighters", "Robo-Pleasures", "Robo-Medics" ],
	"gem_stones": [ "Industrial Gems" ],
	"luxuries": [ "Luxury Foods", "Electric Pets", "Artwork", "Games", "Movies", "Holographics", "Home Entertainment", "Books", "Furniture", "Paleo-Arts", "Archeo-Sims", "Relics", "Religious Texts", "Wood", "Dream Cards", "Hacked Dream Cards" ],
	"firearms": [ "Weaponry", "Combat Drones", "Recon Drones" ],
	"platinum": [],
	"slaves": [ "Slaves", "Black Market Organs", "Altered Embryos", "Counterfeit DNA Sequences" ],
	"furs": [ "Furs" ],
	"radioactives": [ "Plutonium", "Uranium", "Advanced Fuels", "Radium", "Thorium", "Hazardous Waste" ],
	"alien_items": [ "Holy Symbols", "Prayer Books", "Fossils", "Stolen Cargos" ],
	"alloys": [ "Construction Materials", "Pre-Fabs", "Space Salvage", "Plastics", "Synthetics" ],
	"liquor_wines": [ "Liquors" ],
	"narcotics": [ "Brilliance", "Tobacco", "Cheap Spice", "Unlicensed Pharmaceuticals", "Contaminated Products" ],
	"minerals": [ "Iron", "Tungsten", "Nickel", "Quartz" ],
	"computers": [ "Communication Equipment", "Computers", "Home Appliances", "Medical Equipment", "Music Equipment", "Industrial Capacitors", "Artificial Limbs", "Artificial Organs", "Neural Interfaces", "Spy Microchips" ],
	"gold": [ "Gold" ]
};

// Sub-commodity list by group

this.commodityGroups = [
	[ "Weaponry", "Robo-Servants", "Communication Equipment", "Combat Drones", "Recon Drones" ], // GalCop
	[ "Books" ], // GalBook
	[ "Relics", "Religious Texts", "Prayer Books", "Holy Symbols" ], // GalChurch
	[ "Plutonium", "Uranium", "Radium", "Thorium", "Slaves", "Brilliance", "Tobacco", "Cheap Spice", "Liquors", "Weaponry", "Industrial Gems", "Gold", "Platinum", "Robo-Fighters", "Robo-Pleasures", "Hacked Dream Cards", "Space Salvage", "Combat Drones", "Recon Drones", "Black Market Organs", "Altered Embryos", "Counterfeit DNA Sequences", "Stolen Cargos", "Spy Microchips", "Unlicensed Pharmaceuticals", "Hazardous Waste", "Contaminated Products" ], // GalShady
	[ "Medicines", "Robo-Medics", "Medical Equipment", "Artificial Limbs", "Artificial Organs", "Neural Interfaces" ], // GalMedical
	[ "Generic Foods", "Luxury Foods", "Textiles", "Liquors", "Electric Pets", "Games", "Holographics", "Home Entertainment", "Furs", "Furniture", "Robo-Servants" ], // GalCivic
	[ "Plants", "Robo-Servants", "Luxury Foods", "Electric Pets", "Movies", "Holographics", "Furniture", "Liquors", "Tobacco" ], // GalTourism
	[ "Junk Foods", "Grain", "Food Dispensers", "Textiles", "Liquors", "Luxury Foods", "Wood", "Computers", "Home Appliances", "Furs", "Dream Cards" ], // GalShopping
	[ "Farm Animals", "Colture Plants", "Paleo-Arts", "Archeo-Sims" ], // GalNature
	[ "Paleo-Arts", "Archeo-Sims", "Fossils", "Artwork", "Movies", "Holographics", "Music Equipment" ], // GalCulture,
	[ "Generic Foods", "Factory Equipment", "Mining Equipment", "Weaponry", "Construction Materials", "Communication Equipment" ], // GalGovernment
	[ "Books", "Relics", "Liquors", "Medicines", "Electric Pets", "Computers" ], // GalDebug
	[ "Grain", "Generic Foods", "Food Dispensers", "Medicines", "Farm Animals", "Colture Plants", "Junk Foods", "Textiles", "Factory Equipment", "Mining Equipment", "Robo-Servants", "Robo-Workers", "Robo-Fighters", "Robo-Pleasures", "Robo-Medics", "Industrial Gems", "Luxury Foods", "Electric Pets", "Artwork", "Games", "Movies", "Holographics", "Home Entertainment", "Books", "Furniture", "Paleo-Arts", "Archeo-Sims", "Relics", "Religious Texts", "Wood", "Dream Cards", "Hacked Dream Cards", "Weaponry", "Slaves", "Furs", "Plutonium", "Uranium", "Radium", "Thorium", "Advanced Fuels", "Holy Symbols", "Prayer Books", "Fossils", "Construction Materials", "Pre-Fabs", "Space Salvage", "Synthetics", "Plastics", "Liquors", "Brilliance", "Tobacco", "Spice", "Iron", "Tungsten", "Nickel", "Quartz", "Communication Equipment", "Computers", "Home Appliances", "Medical Equipment", "Music Equipment", "Gold", "Industrial Capacitors" ] // EVERYTHING
];

// System governments labels

this.govLabels = ["Anarchy", "Feudal", "Multigovernmental", "Dictatorship", "Communist", "Confederacy", "Democracy", "Corporate"];

var _litf = null;

this.$init = function () {
	_litf = worldScripts.LITF;

	this.$log("[LITF_Common] init");
}

// Print a text message on the Oolite log file
this.$log = function (msg) {
	if (!_litf.litfVars || _litf.litfVars.config.enableLog === true) {
		log(this.name, msg);
	}
};

this.$decodeGroup = function (groupId) {
	var groupLabel = this.groupsLabels[groupId];
	return groupLabel;
}

this.$encodeGroup = function (groupLabel) {
	var groupId = this.groupsLabels.indexOf(groupLabel);
	return groupId;
}

this.$systemEconomy = function () {
	this.$log("[LITF_Common] systemEconomy");

	var economy = system.economy;
	return economy;
}

this.$systemTechLevel = function () {
	this.$log("[LITF_Common] systemTechLevel");

	var tl = system.techLevel;
	return tl;
}

this.$systemGovernment = function () {
	this.$log("[LITF_Common] systemGovernment");

	var gov = system.government;
	return gov;
}

// Replace all occurences of a string in a text
this.$replaceAll = function (find, replace, str) {
	this.$log("[LITF_Common] replaceAll");

	return str.split(find).join(replace);
};

// Generates a random number between two limits
this.$roll = function (min, max) {
	this.$log("[LITF_Common] roll");

	if (min > max) {
		var buf = min;
		min = max;
		max = buf;
	}

	var rv = Math.floor(Math.random() * (max - min + 1)) + min;
	return rv;
};

// // Replace constants in a mission title text
// this.$replaceConstants = function (text, groupId, maxSystemDistance) {
// 	this.$log("[LITF_Common] replaceConstants");

// 	var result = {};
// 	var rtext = null;

// 	if (text.indexOf("%BOOK%") > -1) {
// 		rtext = expandDescription("[litf_Books]");
// 		text = text.replace("%BOOK%", rtext);
// 		if (!result.randBook) { result.randBook = []; }
// 		result.randBook.push(rtext);
// 	}

// 	if (text.indexOf("%ITEM%") > -1) {
// 		rtext = expandDescription("[litf_Items]");
// 		text = text.replace("%ITEM%", rtext);
// 		if (!result.randItem) { result.randItem = []; }
// 		result.randItem.push(rtext);
// 	}

// 	if (text.indexOf("%JOB%") > -1) {
// 		rtext = expandDescription("[litf_Jobs]");
// 		text = text.replace("%JOB%", rtext);
// 		if (!result.randJob) { result.randJob = []; }
// 		result.randJob.push(rtext);
// 	}

// 	if (text.indexOf("%CHARITY%") > -1) {
// 		rtext = expandDescription("[litf_Charity]");
// 		text = text.replace("%CHARITY%", rtext);
// 		if (!result.randCharity) { result.randCharity = []; }
// 		result.randCharity.push(rtext);
// 	}

// 	if (text.indexOf("%PLAYERNAME%") > -1) {
// 		text = text.replace("%PLAYERNAME%", player.name);
// 	}

// 	if (text.indexOf("%NAME%") > -1) {
// 		rtext = randomName() + " " + randomName();
// 		text = text.replace("%NAME%", rtext);
// 		if (!result.randName) { result.randName = []; }
// 		result.randName.push(rtext);
// 	}

// 	if (text.indexOf("%SYSTEM%") > -1) {
// 		var rObj = this.$randomSystem(maxSystemDistance);
// 		text = text.replace("%SYSTEM%", rObj.name);
// 		if (!result.randSystem) { result.randSystem = []; }
// 		result.randSystem.push(rObj);
// 	}

// 	if (text.indexOf("%ART%") > -1) {
// 		rtext = expandDescription("[litf_Art1]") + " " + expandDescription("[litf_Art2]");
// 		text = text.replace("%ART%", rtext);
// 		if (!result.randArt) { result.randArt = []; }
// 		result.randArt.push(rtext);
// 	}

// 	if (text.indexOf("%MUSIC%") > -1) {
// 		rtext = expandDescription("[litf_Music1]") + " " + expandDescription("[litf_Music2]") + " " + expandDescription("[litf_Music3]");
// 		text = text.replace("%MUSIC%", rtext);
// 		if (!result.randMusic) { result.randMusic = []; }
// 		result.randMusic.push(rtext);
// 	}

// 	if (text.indexOf("%MOVIE%") > -1) {
// 		rtext = expandDescription("[litf_Movie1]") + " " + expandDescription("[litf_Movie2]");
// 		text = text.replace("%MOVIE%", rtext);
// 		if (!result.randMovies) { result.randMovies = []; }
// 		result.randMovies.push(rtext);
// 	}

// 	if (text.indexOf("%GOODS%") > -1) {
// 		var goodArrByGroup = this.commodityGroups[12]; // Choose from EVERYTHING
// 		var goodIdx = this.$roll(0, goodArrByGroup.length - 1);

// 		text = text.replace("%GOODS%", goodArrByGroup[goodIdx]);
// 		result.randGood = goodArrByGroup[goodIdx];
// 	}

// 	if (text.indexOf("%RACE%") > -1) {
// 		rtext = randomInhabitantsDescription(true);
// 		text = text.replace("%RACE%", rtext);
// 		if (!result.randRaces) { result.randRaces = []; }
// 		result.randRaces.push(rtext);
// 	}

// 	result.text = text;

// 	this.$log("[replaceConstants] " + JSON.stringify(result));

// 	return result;
// }

// Choose a random system in the input range, that it isn't the current player system
this.$randomSystem = function (maxSystemDistance) {
	this.$log("[LITF_Common] randomSystem");

	var valid   = 0;
	var counter = 0;

	var sysObj    = null; // System object

	while (valid === 0) {
		var rand = Math.floor(Math.random() * 256);

		var distance = this.$getSystemRoute(system.ID, rand).distance;

		if (maxSystemDistance === -1 || distance < maxSystemDistance) {
			var sName = System.systemNameForID(rand);
			if (sName !== system.name) {
				sysObj = {
					id: rand,
					name: sName,
					distance: distance.toFixed(2)
				};
				valid = 1;
			}
		}

		counter++;

		if (counter % 50 === 0 && maxSystemDistance !== -1) {
			maxSystemDistance += 0.5;
		}
	}

	this.$log("randomSystem << " + JSON.stringify(sysObj));

	return sysObj;
};

// Check if a specific time has still to come or not
this.$isTimeExpired = function (startingTime, duration) {
	this.$log("[LITF_Common] isTimeExpired");

	var expired = false;

	var deadline = startingTime + duration;

	if (clock.seconds > deadline) {
		expired = true;
	}

	return expired;
}

// Calculate time from "now" to the specified time, and format the resulting text
this.$formatTime = function (time, remaining) {
	this.$log("[LITF_Common] formatTime");

	if (remaining === true) {
		time = time - clock.seconds;
	}

	var dataTime = this.$secondsData(time);

	var formattedTime = "";

	formattedTime += dataTime.onlyHours + " hours, ";
	formattedTime += dataTime.minutes + " minutes, ";
	formattedTime += dataTime.seconds + " seconds"

    return formattedTime;
}

// Convert a value in seconds in day/hours/only hours/minute/seconds
this.$secondsData = function (seconds) {
	this.$log("[LITF_Common] secondsData");

	var minute = 60;
    var hour = 60 * minute;
    var day = 24 * hour;

    var dd = 0;
    var hh = 0;
    var mm = 0;

	while (seconds > day) {
        dd++;
        seconds -= day;
    }

    while (seconds > hour) {
        hh++;
        seconds -= hour;
    }

    while (seconds > minute) {
        mm++;
        seconds -= minute;
    }

	var obj = {
		days: dd,
		hours: hh,
		onlyHours: hh + (dd * 24),
		minutes: mm,
		seconds: Math.round(seconds)
	}

	this.$log("obj = " + JSON.stringify(obj));

	return obj;
}

// Fisher-Yates Shuffle algorithm for arrays
this.$shuffleArray = function (array) {
	this.$log("[LITF_Common] shuffleArray");

	var currentIndex = array.length;
	var temporaryValue;
	var randomIndex;

	// While there remain elements to shuffle...
	while (0 !== currentIndex) {
		// Pick a remaining element...
		randomIndex = Math.floor(Math.random() * currentIndex);
		currentIndex -= 1;

		// And swap it with the current element.
		temporaryValue      = array[currentIndex];
		array[currentIndex] = array[randomIndex];
		array[randomIndex]  = temporaryValue;
	}

	return array;
}

this.$getSubCommodityPrice = function (subCommodity) {
	var scBasePrice = -1;
	var market = player.ship.dockedStation.market;
	var crKeys = this.$getObjectKeys(this.commodityReference);
	for (var k = 0; k < crKeys.length; k++) {
		var scArr = this.commodityReference[crKeys[k]];
		if (scArr.indexOf(subCommodity) !== -1) {
			scBasePrice = market[crKeys[k]].price;
			break;
		}
	}
	return scBasePrice;
}

// Returns an array with all the keys in an associative object
this.$getObjectKeys = function (object) {
	this.$log("[LITF_Common] getObjectKeys");

	var keys = [];
	for (var key in object) {
		if (object.hasOwnProperty(key)) {
			keys.push(key);
		}
	}

	return keys;
}

// Get a literal ranking from a feedback value
this.$getFeedbackRanking = function (feedback) {
	this.$log("[LITF_Common] getFeedbackRanking");

	var rank = "";

	if (feedback < -100) {
		rank = "Outcast"; // -101 or less
	} else if (feedback < -50) {
		rank = "Criminal"; // -51 to -100
	} else if (feedback < -25) {
		rank = "Unlawful"; // -26 to -50
	} else if (feedback < -10) {
		rank = "Untrusted"; // -11 to -25
	} else if (feedback < 10) {
		rank = "Neutral"; // 9 to -10
	} else if (feedback < 25) {
		rank = "Appreciated"; // 24 to 10
	} else if (feedback < 50) {
		rank = "Helpful"; // 49 to 25
	} else if (feedback < 100) {
		rank = "Trusted"; // 99 to 50
	} else {
		rank = "Renowned"; // 100 or more
	}

	return rank;
}

// Information about a route between two systems
this.$getSystemRoute = function (system1, system2) {
	var infoS1 = System.infoForSystem(galaxyNumber, system1);
	var infoS2 = System.infoForSystem(galaxyNumber, system2);

	var route = infoS1.routeToSystem(infoS2); // route, distance, time
	return route;
}

// Get the general id and increase its value to avoi duplicates
this.$getGeneralId = function () {
	this.$log("[LITF_Common] getGeneralId");

	var generalId = _litf.litfVars.generalId;

	_litf.litfVars.generalId = _litf.litfVars.generalId + 1;

	return generalId;
}

this.$setPlayerFeedback = function (add) {
	this.$log("[LITF_Common] setPlayerFeedback");

	var pFeedback = _litf.litfCommander.feedback;

	pFeedback = pFeedback + add;

	// Check limits

	if (pFeedback > 150) { pFeedback = 150; }
	if (pFeedback < -150) { pFeedback = -150; }

	_litf.litfCommander.feedback = pFeedback;
}

this.$updateStatistics = function (property, groupId, value) {
	this.$log("[LITF_Common] updateStatistics :: " + property + "[" + groupId + "] << " + value);

	var sProperty = _litf.litfCommander.statistics[property];
	_litf.litfCommander.statistics[property][groupId] = sProperty[groupId] + value;
}

this.$padLeft = function (padNumber, padLength, padChar) {
	var numStr = "" + padNumber;

	while (numStr.length < padLength) {
		numStr = padChar + numStr;
	}

	return numStr;
}

// Debug //
this.$exportMissionData = function () {
	this.$log("[LITF] exportMissionData");

	var _md = worldScripts.MissionData;

    var csv = "";
    var separator = "#";

    var k, m, mObj;

    var keyArr = [ "groupId", "typeId" ];

    // First reading - get every key
    for (m = 0; m < _md.missionStore.length; m++) {
        mObj = _md.missionStore[m];
        var mKeys = this.$getObjectKeys(mObj);

        for (k = 0; k < mKeys.length; k++) {
            if (keyArr.indexOf(mKeys[k]) === -1) {
                keyArr.push(mKeys[k]);
            }
        }
    }

    // Header row
    for (k = 0; k < keyArr.length; k++) {
        csv += keyArr[k];
        if (k < keyArr.length - 1) { csv += separator; }
    }
    csv += "\n";

    // Second reading - all the data
    for (m = 0; m < _md.missionStore.length; m++) {
        mObj = _md.missionStore[m];

        // var mRef = _co.$getMissionReference(mObj.type);
        csv += mObj.type.groupId + separator + mObj.type.typeId + separator;

        for (k = 0; k < keyArr.length; k++) {
            var value = mObj[keyArr[k]];
            if (value) {
                csv += value;
            }
            if (k < keyArr.length - 1) { csv += separator; }
        }
        csv += "\n";
    }

    this.$log("--------------------------------------------------\n\n" + csv + "\n\n--------------------------------------------------");
}
