/* eslint-disable semi, no-multi-spaces, quotes, indent, no-tabs, yoda */

"use strict";

this.name = "LITF_MissionData";
this.author = "BeeTLe BeTHLeHeM";
this.copyright = "2018 BeeTLe BeTHLeHeM";
this.description = "Variables and arrays for BBS items and missions data";
this.version = "0.10.0";
this.licence = "CC BY-NC-SA 4.0";

//

// Mission types

this.missionTypes = [ "LOCAL", "CONTACT", "TRANSFER", "RETRIEVE", "TRANSPORT", "CARGO", "SEARCH", "INFO", "TOUR", "KILL" ];

//

this.debugStore = [
    // {
    //     groupId: 11,
    //     index: 0,
    //     local: true,
    //     title: "(TRAINING) This is a mission of type LOCAL",
    //     description: "TBD",
    //     choices: null
    // },
    {
        groupId: 11,
        index: 1,
        title: "(TRAINING) This is a mission of type TRANSPORT from %SYSTEM1% to %SYSTEM2%.",
        description: "Hello. I'm %NAME0%. You have to pick %NAME1% in the %SYSTEM1% system and bring him to the %SYSTEM2% system. For the completion of this task we'll pay you %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "[litf_missionResponseMoneyGroup]" ] // this.litf_missionResponseMoneyGroup
        },
        tasks: [
            {
                index: 1,
                typeId: 4,
                description: "Go to the %SYSTEM1% system, meet %NAME1% and carry him to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W000",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4,
                description: "Carry %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W001"
            }
        ]
    },
    {
        groupId: 11,
        index: 2,
        title: "(TRAINING) This is a mission of type TRANSPORT from here to %SYSTEM1%.",
        description: "Hello. I'm %NAME0%. I need a ship to go to the %SYSTEM1% system. For the completion of this task I'll pay you %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "[litf_missionResponseMoneyPassenger]" ] // this.litf_missionResponseMoneyPassenger
        },
        tasks: [
            {
                index: 1,
                typeId: 4,
                description: "Bring %NAME0% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W001"
            }
        ]
    },
    {
        groupId: 11,
        index: 3,
        title: "(TRAINING) This is a mission of type TRANSPORT (group) from here to %SYSTEM1%.",
        description: "Hello. I'm %NAME0%. Me and my friends need a ship to go to the %SYSTEM1% system. For the completion of this task I'll pay you %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 2, 7 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "[litf_missionResponseMoneyGroup]" ] // this.litf_missionResponseMoneyGroup
        },
        tasks: [
            {
                index: 1,
                typeId: 4,
                description: "Bring %PASSENGERS% people to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W001"
            }
        ]
    },
    {
        groupId: 11,
        index: 4,
        title: "(TRAINING) This is a mission of type CARGO from here to %SYSTEM1%.",
        description: "Hello. I'm %NAME0%. I need to send a shipment of %GOODS% to the %SYSTEM1% system. For the completion of this task I'll pay you %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "It's a simple commercial trip." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5,
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "W002"
            }
        ]
    }
];

this.missionWaitingStore = [
    // Debug ------------------------------------------------------------------
    {
        label: "W000",
        title: "(TRAINING) Commander %PLAYERNAME%, I'm waiting for you to leave this system.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm %NAME1%. If you're ready we can leave immediately.",
                choice: {
                    "01_NEXTTASK": "\"Ok, go to the hangar and we go.\"",
                    "99_QUIT": "Hang up."
                }
            }
        ]
    },
    {
        label: "W001",
        title: "(TRAINING) Commander %PLAYERNAME%, get your payment.",
        steps: [
            {
                index: 1,
                description: "-- Closing transaction --",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    {
        label: "W002",
        title: "(TRAINING) Commander %PLAYERNAME%, we are offloading the cargo from your ship. You can get your payment.",
        steps: [
            {
                index: 1,
                description: "-- Closing transaction --",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    // Generic ----------------------------------------------------------------
    {
        label: "G1",
        title: "REWARD: Commander %PLAYERNAME%, get your payment.",
        steps: [
            {
                index: 1,
                description: "<Please accept the transaction to close the deal.>",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    {
        label: "G2",
        title: "LOOK HERE: Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello Commander %PLAYERNAME%, I'm glad you're here. Can we leave for our destination?",
                choice: {
                    "01_GOTO_2": "\"Yes, we can leave now.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "G3",
        title: "HANGAR: Commander %PLAYERNAME%, we are offloading the cargo from your ship. You can get your payment.",
        steps: [
            {
                index: 1,
                description: "-- Closing transaction --",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    {
        label: "G3.1",
        title: "HANGAR: Waiting Commander %PLAYERNAME% to load cargo onto the ship.",
        steps: [
            {
                index: 1,
                description: "Hi. We're going to load a shipment of %GOODS% on you ship, as agreed.",
                choice: {
                    "01_GOTO_2": "\"Yes, proceed.\"",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            },
            {
                index: 2,
                description: "We have loaded the cargo. You can leave when you want. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "G4",
        title: "LOOK HERE: Waiting for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME1%. Can we leave to our destination now?",
                choice: {
                    "01_COMPLETE": "\"Yes, we can leave now.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },

    // GalCop -----------------------------------------------------------------
    {
        label: "W0.1.1",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. There's something I can do for you? I'm pretty busy at the moment.",
                choice: {
                    "01_GOTO_2": "\"I come from %SYSTEM0% with some informations for you. GalCop is the sender.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Can you trasmit me these info?",
                choice: {
                    "01_GOTO_3": "\"Here they are.\" and send the info."
                }
            },
            {
                index: 3,
                description: "Yes, I was awaiting this. Good service citizen. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.1.2",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. There's something I can do for you? I'm pretty busy at the moment.",
                choice: {
                    "01_GOTO_2": "\"I come from %SYSTEM0%, I have some equipment for you. GalCop is the sender.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Oh yes, I was awaiting that. Are you sending me the package?",
                choice: {
                    "01_GOTO_3": "\"Yes, just sent through the station network.\""
                }
            },
            {
                index: 3,
                description: "Good service citizen. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.2.5.1",
        title: "MEETING: Waiting Commander %PLAYERNAME% for a chat.",
        steps: [
            {
                index: 1,
                description: "Hello citizen. You have to report the following info to agent %NAME2%.",
                choice: {
                    "01_GOTO_2": "\"Ok, I'm listening.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "...and that's all. Do your work. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.2.5.2",
        title: "GALCOP: Waiting for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Citizen, you can give me the info you gathered.",
                choice: {
                    "01_GOTO_2": "Report the data.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Good service citizen. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.3.3.1",
        title: "MEETING: Waiting Commander %PLAYERNAME% for a chat.",
        steps: [
            {
                index: 1,
                description: "I suppose you are here to pick the data I gathered.",
                choice: {
                    "01_GOTO_2": "\"Yes, GalCop sent me. They said it's an urgent matter.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Yes. I have sent you the data. Hurry and bring them back. Farewell.",
                choice: {
                    "01_NEXTTASK": "Take the data and hang up."
                }
            }
        ]
    },
    {
        label: "W0.3.3.2",
        title: "GALCOP: Waiting for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Citizen, give us the data you obtained.",
                choice: {
                    "01_GOTO_2": "\"I'm just sending it to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "The data isn't corrupted. Good service citizen. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.3.4.1",
        title: "MEETING: Waiting Commander %PLAYERNAME% for a chat.",
        steps: [
            {
                index: 1,
                description: "Hello citizen. Listen to me and report to the GalCop officer who sent you.",
                choice: {
                    "01_GOTO_2": "\"Ok, I'm listening.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "...and that's all. Do your work. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.3.4.2",
        title: "GALCOP: Waiting for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Citizen, give us the data you obtained.",
                choice: {
                    "01_GOTO_2": "Report the data.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Good service citizen. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W0.4",
        title: "GALCOP: Commander %PLAYERNAME%, get your payment.",
        steps: [
            {
                index: 1,
                description: "<Please accept the transaction to close the deal.>",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    {
        label: "W0.4.7",
        title: "GALCOP: Commander %PLAYERNAME%, waiting to proceed.",
        steps: [
            {
                index: 1,
                description: "Hello citizen, can we proceed with the transfer?",
                choice: {
                    "01_NEXTTASK": "\"Yes, we can leave right now.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "W0.4.8",
        title: "GALCOP: Looking for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME1%, can we proceed with the transfer?",
                choice: {
                    "01_NEXTTASK": "\"We can leave now.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "W0.4.12.1",
        title: "WAITING: Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Here you are. Let's get out of here NOW!",
                choice: {
                    "01_NEXTTASK": "\"Ok let's go.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    // GalBook ----------------------------------------------------------------
    {
        label: "W1.1.1",
        title: "LOOK HERE: Commander %PLAYERNAME%, where is my book?",
        steps: [
            {
                index: 1,
                description: "Here we are. Do you have my book?",
                choice: {
                    "01_GOTO_2": "\"Yes, I have it right here.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Can you send it to me via the station network?",
                choice: {
                    "01_GOTO_3": "\"Done.\""
                }
            },
            {
                index: 3,
                description: "At last! '%BOOK%! I looked forward to this moment! Take your payment! Goodbye!",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W1.2.3.1",
        title: "DELIVER: I have a book for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm %NAME1%. I have a book for you.",
                choice: {
                    "01_GOTO_2": "\"Yes, please, send it to me.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Done. Please, keep it safe. It's a valuable copy.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W1.2.3.2",
        title: "WAITING: Commander %PLAYERNAME% with my book.",
        steps: [
            {
                index: 1,
                description: "Here we are. Where's the book?",
                choice: {
                    "01_GOTO_2": "Send the book.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ah, perfect. Very good conditions - near mint. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W1.3.2.1",
        title: "DELIVER: I have a book for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm %NAME1%. I have a book for you.",
                choice: {
                    "01_GOTO_2": "\"Yes, please, send it to me.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Done. Bring my salutes to %NAME0%. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W1.3.2.2",
        title: "WAITING: Commander %PLAYERNAME% with my book.",
        steps: [
            {
                index: 1,
                description: "You have returned at last. Where's the book?",
                choice: {
                    "01_GOTO_2": "Send the book.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ah, perfect. Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    // GalChurch --------------------------------------------------------------
    {
        label: "W2.1.2",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. What do you want?",
                choice: {
                    "01_GOTO_2": "\"Hmm... the Church of %SYSTEM1% wants you to read this sacred text and join them.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ah.",
                choice: {
                    "01_GOTO_3": "\"I'm sending you the text.\""
                }
            },
            {
                index: 3,
                description: "Ok. Bye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W2.2.3.1",
        title: "WAITING: Church envoy %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm Acolyte %NAME1%. I will bring to your ship the holy alien artifacts for the transport.",
                choice: {
                    "01_GOTO_2": "\"Yes, thank you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Done. My blessing to you and Acolyte %NAME2%. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W2.2.3.2",
        title: "WAITING: Gentle %PLAYERNAME% with our sacred materials.",
        steps: [
            {
                index: 1,
                description: "I thank you, %PLAYERNAME%, for your service.",
                choice: {
                    "01_GOTO_2": "\"You're welcome. You can pick up the artifacts.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Holy alien artifacts, to be precise. Thank you. The Church bless you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W2.3.1.1",
        title: "WAITING: Church envoy %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm Acolyte %NAME1%. Can I send you the materials for Acolyte %NAME0%?.",
                choice: {
                    "01_GOTO_2": "\"Yes, thank you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Done. My blessing to you and Acolyte %NAME0%. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W2.3.1.2",
        title: "WAITING: Looking forward to encounter %PLAYERNAME% again.",
        steps: [
            {
                index: 1,
                description: "I thank you, %PLAYERNAME%, for your service.",
                choice: {
                    "01_GOTO_2": "\"You're welcome. Here are your materials.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Thank you. The church bless you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W2.4",
        title: "CHURCH: Commander %PLAYERNAME%, get your payment.",
        steps: [
            {
                index: 1,
                description: "<Please accept the transaction to close the deal.>",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    {
        label: "W2.4.6",
        title: "CHURCH: Commander %PLAYERNAME%, ready to leave.",
        steps: [
            {
                index: 1,
                description: "Hello kindred soul, I'm Priest %NAME1%. Can we proceed with the transfer?",
                choice: {
                    "01_NEXTTASK": "\"We can leave now.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "W2.4.8",
        title: "CHURCH: Church followers eagerly waiting for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello kindred soul, We are ready to start our pilgrimage.",
                choice: {
                    "01_NEXTTASK": "\"We can leave now.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    // GalShady ---------------------------------------------------------------
    {
        label: "W3.1.1",
        title: "HELP: Dear friend %PLAYERNAME%, I'm waiting for you.",
        steps: [
            {
                index: 1,
                description: "Good day, friend. Do you have something for me?",
                choice: {
                    "01_GOTO_2": "\"Yes, some... 'useful data'.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Perfect. It's the data I like most!",
                choice: {
                    "01_GOTO_3": "\"Here you are.\""
                }
            },
            {
                index: 3,
                description: "Thank you, friend.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W3.2.3.1",
        title: "HURRY: %PLAYERNAME%, take away this thing.",
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%, and you must pick up this thing. Deliver it to %NAME2% in the %SYSTEM2%.",
                choice: {
                    "01_GOTO_2": "\"Ok... but what is it?\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "The thing? It's... a thing. It seems a box but... Doesn't matter. I almost forgot! It's a surprise! %NAME2% doesn't know of the thing.",
                choice: {
                    "01_GOTO_3": "\"Ah... ok.\""
                }
            },
            {
                index: 3,
                description: "Do what you got to do. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W3.2.3.2",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hello, %NAME2% here, what do you want?",
                choice: {
                    "01_GOTO_2": "\"A th... box for you. A present.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "A present? Mh. Ok, send it to me.",
                choice: {
                    "01_GOTO_3": "\"Sent just now.\""
                }
            },
            {
                index: 3,
                description: "Bye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W3.3.2.1",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME1%. What can I do for you?",
                choice: {
                    "01_GOTO_2": "\"%NAME0% wants some package back.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "%NAME0%? Hmm... yes I understand. Please wait a moment...",
                choice: {
                    "01_GOTO_3": "Wait."
                }
            },
            {
                index: 3,
                description: "I've sent you the package. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W3.3.2.2",
        title: "WAITING: %PLAYERNAME% with my package.",
        steps: [
            {
                index: 1,
                description: "You have brought my package, right?",
                choice: {
                    "01_GOTO_2": "Send the package via the station network.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Bye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W3.4.4",
        title: "NOW: Commander %PLAYERNAME%, ready to leave.",
        steps: [
            {
                index: 1,
                description: "Let's get out of there.",
                choice: {
                    "01_NEXTTASK": "\"Ok.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "W3.4.4",
        title: "WAITING: Commander %PLAYERNAME%, we are ready to leave.",
        steps: [
            {
                index: 1,
                description: "We can go now.",
                choice: {
                    "01_NEXTTASK": "\"Ok.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "W3.4.9.1",
        title: "PASSAGE: Commander %PLAYERNAME%, I'm ready to leave.",
        steps: [
            {
                index: 1,
                description: "They send you to bring me to safety, right? Let's go now, I don't feel safe here.",
                choice: {
                    "01_NEXTTASK": "\"Ok.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    // GalMedical -------------------------------------------------------------
    {
        label: "W4.1.1",
        title: "PSA: Medical team available here!",
        steps: [
            {
                index: 1,
                description: "Hello, I'm Doctor %NAME1%. There's something I can do for you?",
                choice: {
                    "01_GOTO_2": "\"Your colleagues from %SYSTEM0% want to know how goes the work.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Oh right. We're very busy and I forgot to update them. Thank you. I'll answer to them right now.",
                choice: {
                    "01_COMPLETE": "\"Perfect. Goodbye.\""
                }
            }
        ]
    },
    {
        label: "W4.1.2",
        title: "SCIENCE: Looking for professionals for medical research.",
        steps: [
            {
                index: 1,
                description: "Hello, I'm Doctor %NAME1%. There's something I can do for you?",
                choice: {
                    "01_GOTO_2": "\"Your colleagues from %SYSTEM0% want to know how goes the work.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Yes, I must update them on the stage of our research. It's going pretty well but the work is very intensive and leave us little time for other. Thanks for your reminding.",
                choice: {
                    "01_COMPLETE": "\"Ok then. Goodbye.\""
                }
            }
        ]
    },
    {
        label: "W4.2.5.1",
        title: "URGENT: Doctor %NAME1% looking for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm Doctor %NAME1%. Are you here to take the donor blood?",
                choice: {
                    "01_GOTO_2": "\"Yes, you can do it now.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ok, done. Thank you. Please hurry.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W4.2.5.2",
        title: "HOSPITAL: Emergency!! Donor blood needed. Do your part.",
        steps: [
            {
                index: 1,
                description: "Do you have the donor blood we need?",
                choice: {
                    "01_GOTO_2": "\"Yes, taken from %NAME1%. You can pick it up now.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "This is a relief. Thank you. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W4.3.4.1",
        title: "PICK-UP: I'm Doctor %NAME1% and I'm looking for Commander %PLAYERNAME%",
        steps: [
            {
                index: 1,
                description: "Hello. I'm Doctor %NAME1%. I have a box of documents for you.",
                choice: {
                    "01_GOTO_2": "\"Yes, please, send it to me.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Done. Thank you. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W4.3.4.2",
        title: "DOCUMENTS: Commander %PLAYERNAME% answer here when you return.",
        steps: [
            {
                index: 1,
                description: "Have you taken the documents I need?",
                choice: {
                    "01_GOTO_2": "Send all the documents.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Thank you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W4.4.11.1",
        title: "PICK-UP: Commander %PLAYERNAME% for ship-ambulance job.",
        steps: [
            {
                index: 1,
                description: "Hello, we have the passenger. Can we bring him into your ship?",
                choice: {
                    "01_GOTO_2": "\"Yes, please.\"",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            },
            {
                index: 2,
                description: "Done. Please leave quickly. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W4.4.11.2",
        title: "HOSPITAL: Waiting for Commander %PLAYERNAME% with a sick passenger.",
        steps: [
            {
                index: 1,
                description: "We are bringing the passenger to the hospital. Thanks for your service.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    // GalCivic ---------------------------------------------------------------
    {
        label: "W5.1.1",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME1%. Do you have a package for me?",
                choice: {
                    "01_GOTO_2": "\"Yes, exactly.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Can you send it to me, please?",
                choice: {
                    "01_GOTO_3": "\"Just done.\""
                }
            },
            {
                index: 3,
                description: "Thank you, friend.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W5.1.2",
        title: null,
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. Can I do something for you?",
                choice: {
                    "01_GOTO_2": "\"I come from %SYSTEM0%. %NAME0% is worried about you and the family.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Oh! We had a lot of problem with the communication network here. We'll try to make contact again soon. Things aren't too bad. Thanks for your interest.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W5.3.3.1",
        title: "LOOK HERE: Commander %PLAYERNAME%, I have %ITEM% for you.",
        steps: [
            {
                index: 1,
                description: "Hello. I'm %NAME1%. Can I send you the stuff %NAME0% has forgotten here?",
                choice: {
                    "01_GOTO_2": "\"Yes, please, send it to me.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Thank you. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W5.3.3.2",
        title: "ITEMS: Commander %PLAYERNAME%, bring back my stuff please!",
        steps: [
            {
                index: 1,
                description: "Where is my stuff?",
                choice: {
                    "01_GOTO_2": "\"Right here, I'll going to send it to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Thank you. I was desperate without.",
                choice: {
                    "01_COMPLETE": "(\"Go figure.\") Hang up."
                }
            }
        ]
    },
    {
        label: "W5.4.8.1",
        title: "HEY YOU: Commander %PLAYERNAME%, I'm waiting for you.",
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. Can we leave now? I have a bad feeling...",
                choice: {
                    "01_NEXTTASK": "\"Ok, let's leave.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    // GalTourism missions ----------------------------------------------------
    {
        label: "W6.1.1",
        title: "DELUXOR HOTELS: Exaggerate luxury for a deluxe holiday!",
        steps: [
            {
                index: 1,
                description: "Hi, this is the DeLuxor hotels reception. What can I do for you?",
                choice: {
                    "01_GOTO_2": "\"I need to cancel a room reservation for %NAME0% from the %SYSTEM0% system.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Are you %NAME0%?",
                choice: {
                    "01_GOTO_3": "\"No. %NAME0% has employed me to attend this because he can't contact you. I'm sending you the documents I was given.\""
                }
            },
            {
                index: 3,
                description: "Hm. I see. We'll need a further confirmation from %NAME0%, though. Thanks, DeLuxor hotels wishes you a good day.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W6.2.2.1",
        title: "SPACEPORT: Baggage reclamation office open for service.",
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. Do you wish to collect your baggage?",
                choice: {
                    "01_GOTO_2": "\"Not mine, but %NAME2% baggage. Here's the documents.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ok, I see. All right, you can collect the baggage. Good day.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W6.2.2.2",
        title: "WAITING: Commander %PLAYERNAME% and my baggage.",
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME2%. Do you have my baggage?",
                choice: {
                    "01_GOTO_2": "\"Yes, I've collected it from the %SYSTEM1% spaceport. I'm sending it to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ooh thank you. I was very worried. Thanks again. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W6.3.3.1",
        title: "SPACEPORT: Baggage reclamation office open for service.",
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. Do you wish to collect your baggage?",
                choice: {
                    "01_GOTO_2": "\"Not mine, but %NAME0% baggage. Here's the documents.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ok, I see. All right, you can collect the baggage. Good day.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W6.3.3.2",
        title: "WAITING: Commander %PLAYERNAME% and my baggage.",
        steps: [
            {
                index: 1,
                description: "Welcome back, Commander. Do you have my baggage?",
                choice: {
                    "01_GOTO_2": "\"Yes, it's here. I'm sending it to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Thanks for your service. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W6.4",
        title: "DELUXOR: Commander %PLAYERNAME%, get your payment.",
        steps: [
            {
                index: 1,
                description: "<Please accept the transaction to close the deal.>",
                choice: {
                    "01_COMPLETE": "Accept and hang up."
                }
            }
        ]
    },
    // GalShopping missions ---------------------------------------------------

    // GalNature --------------------------------------------------------------
    {
        label: "W8.3.1.1",
        title: "BOTANICAL: Commander %PLAYERNAME%, plants specimens are ready for transport.",
        steps: [
            {
                index: 1,
                description: "I'm %NAME1%, a botanist. We have the specimens that you must return to %NAME0%.",
                choice: {
                    "01_GOTO_2": "\"Ok, bring them to my ship.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "We are going to the hangar. Hurry up.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W8.3.1.2",
        title: "BOTANICAL: Commander %PLAYERNAME%, answer here to deliver the specimens.",
        steps: [
            {
                index: 1,
                description: "Can we take the plants specimens now?",
                choice: {
                    "01_GOTO_2": "\"Yes, you can take them.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Thank you. We'll provide better conditions for these plants. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    // GalCulture -------------------------------------------------------------
    {
        label: "W9.1.1",
        title: "LOOK HERE: I'm waiting for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME1% and you should have a painting for me.",
                choice: {
                    "01_GOTO_2": "\"Yes. '%PAINTING%'. I'm sending it to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "I can't wait to put it in my collection! Thank you, Commander.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W9.2.2.1",
        title: "RELOCATION: Waiting for appointee Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. I believe you must transport '%PAINTING%' to the art gallery in %SYSTEM2%, right?",
                choice: {
                    "01_GOTO_2": "\"Yes, exactly. %NAME0% has sent me here.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ok, I see. I'm taking the painting to your ship. Please be careful.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W9.2.2.2",
        title: "OPENING SOON: Art gallery currently preparing next big painting exposition.",
        steps: [
            {
                index: 1,
                description: "Hello, I'm %NAME2%, what can I do for you?",
                choice: {
                    "01_GOTO_2": "\"I have a painting from %NAME1%, '%PAINTING%', for the gallery.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Oh yes, great! We are going to pick it up from your ship. Thanks for your work.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W9.3.3.1",
        title: "ART RESTORER: We'll give a new life to your old precious.",
        steps: [
            {
                index: 1,
                description: "Hi, I'm %NAME1%. Do you have something you want repaired?",
                choice: {
                    "01_GOTO_2": "\"No, thanks. %NAME1% has sent me to pick up a painting: '%PAINTING%'.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Oh yes, one of my better works. I'll take it to your ship. Thanks and goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W9.3.3.2",
        title: "REMINDER: A painting from Commander %PLAYERNAME%",
        steps: [
            {
                index: 1,
                description: "Welcome back, Commander. Do you have my painting?",
                choice: {
                    "01_GOTO_2": "\"Yes, it's here. I'm sending it to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Ah, a very fine job. Thank you Commander. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    // GalGovernment ----------------------------------------------------------
    {
        label: "W10.1.1",
        title: null,
        steps: [
            {
                index: 1,
                description: "Yes?",
                choice: {
                    "01_GOTO_2": "\"I come from %SYSTEM0%.\" Tell the given passcode.",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "I understand. I know I'm late with my report, but they always think everything is so easy... I'll send a detailed message very soon. No need to report back. Farewell.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W10.2.3.1",
        title: "DIPLOMACY: %SYSTEM0% consulate currently open to the public.",
        steps: [
            {
                index: 1,
                description: "Hello citizen. What can we do for you?",
                choice: {
                    "01_GOTO_2": "\"I was appointed by %SYSTEM0% government to transfer some diplomatic documents to %SYSTEM2%.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Yes, we received communication. We are sending the documents to you. Thanks citizen. Goodbye.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W10.2.3.2",
        title: "DIPLOMACY: %SYSTEM0% consulate currently open to the public.",
        steps: [
            {
                index: 1,
                description: "Hello citizen. What can we do for you?",
                choice: {
                    "01_GOTO_2": "\"I was appointed by %SYSTEM0% government to transfer some diplomatic documents from %SYSTEM1%.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Yes, we received communication.",
                choice: {
                    "01_GOTO_3": "\"I'm sending the documents to you right now.\""
                }
            },
            {
                index: 3,
                description: "Thanks citizen. Goodbye.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W10.3.2.1",
        title: null,
        steps: [
            {
                index: 1,
                description: "I'm %NAME1% Can I do something for you?",
                choice: {
                    "01_GOTO_2": "\"The %SYSTEM0% government has sent me here.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "I understand. I'm sending you the documents. Keep them safe.",
                choice: {
                    "01_NEXTTASK": "Hang up."
                }
            }
        ]
    },
    {
        label: "W10.3.2.2",
        title: "GOVERNMENT: Front office open for Commander %PLAYERNAME%.",
        steps: [
            {
                index: 1,
                description: "The stolen dossiers?",
                choice: {
                    "01_GOTO_2": "\"Here they are, I'm sending them to you.\"",
                    "99_QUIT": "Hang up."
                }
            },
            {
                index: 2,
                description: "Good service citizen. Your government is proud of you.",
                choice: {
                    "01_COMPLETE": "Hang up."
                }
            }
        ]
    },
    {
        label: "W10.4.8.1",
        title: "DIPLOMATIC: Waiting for Commander %PLAYERNAME% for the trip back home.",
        steps: [
            {
                index: 1,
                description: "Hello citizen. We are escorting glorious officer %NAME1% to your ship. We can leave just after.",
                choice: {
                    "01_NEXTTASK": "\"Ok.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    },
    {
        label: "W10.4.9.1",
        title: "NOSTALGIC: Commander %PLAYERNAME%, let's get back home.",
        steps: [
            {
                index: 1,
                description: "Hello citizen. I'm %NAME1%. I'm ready to left for %SYSTEM0%, when you're ready.",
                choice: {
                    "01_NEXTTASK": "\"Ok, let's go.\" and hang up.",
                    "99_QUIT": "\"Hold on while I make room.\" then hang up."
                }
            }
        ]
    }
];

this.missionStore = [
    // GalCop Missions --------------------------------------------------------
    // CONTACT
    {
        groupId: 0,
        index: 1,
        title: "GALCOP: Deliver sensitive info to an agent.",
        description: "Hello citizen. We need a pilot for the delivery of sensitive informations to our agent %NAME1%, currently in the %SYSTEM1% system. GalCop will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "A GalCop information drive",
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and deliver sensitive informations to agent %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.1.1",
                unaware: true
            }
        ]
    },
    {
        groupId: 0,
        index: 2,
        title: "GALCOP: Deliver equipment to an agent.",
        description: "Hello citizen. Our agent %NAME1%, currently in the %SYSTEM1% system, need some equipment. We do not have transport going that way. GalCop will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "A GalCop equipment kit",
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and deliver equipment to agent %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.1.2",
                unaware: true

            }
        ]
    },
    // TRANSFER
    {
        groupId: 0,
        index: 5,
        title: "GALCOP: Courier needed.",
        description: "Hello citizen, we have agent %NAME1% in the %SYSTEM1% that must transmit important info to agent %NAME2% in %SYSTEM2%. We don't trust normal comm channels this time, so we resort to a courier. GalCop will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system and meet with agent %NAME1%. Bring the info to %SYSTEM2%.",
                generate: { systems: 1, names: 1 },
                parcel: "A GalCop information drive",
                waitingMission: "W0.2.5.1"
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring the info to agent %NAME2%, in the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.2.5.2"
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 0,
        index: 3,
        title: "GALCOP: A fast ship to retrieve data from an agent.",
        description: "Hello citizen, we need someone to go to the %SYSTEM1% system and meet our agent %NAME1%. We need the data that will be delivered to you. GalCop will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system, meet with agent %NAME1% to pick up the data, and return to %SYSTEM0%.",
                generate: { systems: 1, names: 1 },
                parcel: "A GalCop information drive",
                waitingMission: "W0.3.3.1",
                urgent: true
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring back the data to the GalCop officer in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W0.3.3.2"
            }
        ]
    },
    {
        groupId: 0,
        index: 4,
        title: "GALCOP: Contact an agent and report info.",
        description: "Hello citizen, we need someone to report us the last informations from our agent %NAME1% in the to the %SYSTEM1% system. GalCop will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and meet with agent %NAME1%. Report to the GalCop officer in the %SYSTEM0% system.",
                generate: { systems: 1, names: 1 },
                parcel: "A GalCop information drive",
                waitingMission: "W0.3.4.1",
                urgent: true
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Report to the GalCop officer in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W0.3.4.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 0,
        index: 6,
        title: "GALCOP: Transport an agent to another system.",
        description: "Hello citizen, I need a ship to transport me to the GalCop center in the %SYSTEM1%. GalCop will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring agent %NAME0% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W0.4"
            }
        ]
    },
    {
        groupId: 0,
        index: 7,
        title: "GALCOP: A ship for an agent relocation.",
        description: "Hello citizen, we need someone to transport an agent from the GalCop center in the %SYSTEM1% to the one in %SYSTEM2%. GalCop will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring GalCop agent from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.4.7",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring GalCop agent to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W0.4"
            }
        ]
    },
    {
        groupId: 0,
        index: 8,
        title: "GALCOP: Bring back an agent to this station.",
        description: "Hello citizen, we need someone to transport an agent here from the GalCop center in the %SYSTEM1%. GalCop will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring GalCop agent from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.4.7",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring GalCop agent to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W0.4"
            }
        ]
    },
    {
        groupId: 0,
        index: 9,
        title: "GALCOP: Transport a witness to a trial.",
        description: "Hello citizen, we need someone to transport an important witness to a trial to be held in the %SYSTEM1%. GalCop will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        risk: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring witness %NAME0% to the trial in the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W0.4"
            }
        ]
    },
    {
        groupId: 0,
        index: 10,
        title: "GALCOP: Transport a witness to a trial.",
        description: "Hello citizen, we need someone to transport an important witness in the %SYSTEM1% system to a trial to be held in %SYSTEM2%. GalCop will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Go to the %SYSTEM1% system to pickup a witness, and bring him to a trial in %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.4.8",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring witness %NAME1% to a trial in the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W0.4"
            }
        ]
    },
    {
        groupId: 0,
        index: 12,
        title: "GALCOP: Emergency transport for an agent.",
        description: "Hello citizen. An agent needs to be extracted ASAP from the %SYSTEM1% system. You have to transport here where we will transfer him in a secure location. GalCop will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 2,
        customResponses: {
            money: [ "This is an emergency situation." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring GalCop agent from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.4.12.1",
                urgent: true,
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring GalCop agent to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                urgent: true,
                waitingMission: "W0.4"
            }
        ]
    },
    {
        groupId: 0,
        index: 13,
        title: "GALCOP: Help for a political personality.",
        description: "Hello citizen. We need someone to pick up a dissident politician, %NAME1%, from the %SYSTEM1% system and transport him to %SYSTEM2%. This is an urgent mission, as his government is still searching for him.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "This is an emergency situation." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring dissident %NAME1% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W0.4.7",
                urgent: true,
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring dissident %NAME1% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                urgent: true,
                waitingMission: "W0.4"
            }
        ]
    },
    // CARGO
    {
        groupId: 0,
        index: 11,
        title: "GALCOP: Looking for a ship to transport cargo.",
        description: "Hello citizen, we need someone to transport a shipment of %GOODS% to the %SYSTEM1% system. GalCop will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "Just the ordinary GalCop payment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    // GalBook Missions -------------------------------------------------------
    // CONTACT
    {
        groupId: 1,
        index: 1,
        title: "NOTICE: Book delivery to another system.",
        description: "Hi, I'm %NAME0% and I sold '%BOOK%' to %NAME1%, but I have no way to hand over the book. Could you help me? I will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "A copy of '%BOOK%'",
        customResponses: {
            money: [ "These are old books - ancient, I could say." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and deliver '%BOOK%' to %NAME1%.",
                generate: { systems: 1, names: 1, books: 1 },
                waitingMission: "W1.1.1"
            }
        ]
    },
    // TRANSFER
    {
        groupId: 1,
        index: 3,
        title: "SHIP REQUESTED: A safe transfer for a book.",
        description: "Hello, I'm %NAME0% and I received a request for a transfer job. %NAME1% in the %SYSTEM1% wants a safe passage for a copy of '%BOOK%' to %NAME2% in %SYSTEM2%. What do you think? I pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "These are old books - ancient, I could say." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system and get '%BOOK%' from %NAME1%. Bring the book to %SYSTEM2%.",
                generate: { systems: 1, names: 1, books: 1 },
                parcel: "A copy of '%BOOK%'",
                waitingMission: "W1.2.3.1"
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Deliver '%BOOK%' to %NAME2% in the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W1.2.3.2"
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 1,
        index: 2,
        title: "SHIP REQUESTED: I need to get back a book.",
        description: "Hi, I'm %NAME0% and I have bought '%BOOK%' from %NAME1% in the %SYSTEM1% system, but I have no way to get the book. Can you help me? I pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "These are old books - ancient, I could say." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get '%BOOK%' from %NAME1%. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1, books: 1 },
                parcel: "A copy of '%BOOK%'",
                waitingMission: "W1.3.2.1"
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring '%BOOK%' to %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W1.3.2.2"
            }
        ]
    },
    // CARGO
    {
        groupId: 1,
        index: 4,
        title: "SHIPMENT: Can you transport some stuff?",
        description: "Hello. I'm %NAME0%. My business needs to send a shipment of %GOODS% to the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "We're talking about valuable books." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    // GalChurch Missions -----------------------------------------------------
    // CONTACT
    {
        groupId: 2,
        index: 2,
        title: "INSPIRATION: Contact a wise man to join our Church.",
        description: "Hello, kindred soul. We know that there is a wise being in the %SYSTEM1% system, under the name %NAME1%. Could you bring our sacred text to him? We would like to invite him to our Church. We will pay you %REWARD% credits for this service.",
        choices: "mission",
        currentTask: 1,
        parcel: "A sacred text",
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and talk to the wise %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W2.1.2",
                unaware: true
            }
        ]
    },
    // TRANSFER
    {
        groupId: 2,
        index: 3,
        title: "SACRED: We need a ship to transfer some holy alien artifacts.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to pickup some holy alien artifacts from Acolyte %NAME1% of the Church of %SYSTEM1%, artifacts that will be transported to Acolyte %NAME2% of the Church of %SYSTEM2%. The church will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system and get the holy alien artifacts from Acolyte %NAME1%. Bring the artifacts to the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                parcel: "Some alien artifacts",
                waitingMission: "W2.2.3.1"
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring the artifacts to Acolyte %NAME2% in the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W2.2.3.2"
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 2,
        index: 1,
        title: "HOLY: We need to transport back some Church material.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to bring here various materials currently in possession of Acolyte %NAME1% od the Church of %SYSTEM1%. The Church will pay %REWARD% credits for your service.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get the Church materials from Acolyte %NAME1%. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1 },
                parcel: "Boxes of religious materials",
                waitingMission: "W2.3.1.1"
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring the Church materials to Acolyte %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W2.3.1.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 2,
        index: 4,
        title: "SPIRITUAL: An eminent priest is awaited for a religious service.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to bring Priest %NAME1% to the Church of %SYSTEM1%. The Church will pay %REWARD% credits for your service.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 1,
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Priest %NAME1% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W2.4"
            }
        ]
    },
    {
        groupId: 2,
        index: 5,
        title: "SHIP WANTED: A group of missionaries is leaving for another system.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to bring a group of missionaries to the %SYSTEM1% system. The Church will pay %REWARD% credits for your service.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 3, 7 ],
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring a group of %PASSENGERS% missionaries to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W2.4"
            }
        ]
    },
    {
        groupId: 2,
        index: 6,
        title: "SPIRITUAL: An eminent priest is awaited for a religious service.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to bring Priest %NAME1% from the %SYSTEM1% system to the Church of %SYSTEM2%. The Church will pay %REWARD% credits for your service.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Priest %NAME1% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W2.4.6",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring Priest %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W2.4"
            }
        ]
    },
    {
        groupId: 2,
        index: 7,
        title: "TRANSFER: Moving a priest from one church to another.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to bring Priest %NAME1% from the Church of %SYSTEM1% to the %SYSTEM2% system. The Church will pay %REWARD% credits for your service.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Priest %NAME1% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W2.4.6",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring Priest %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W2.4"
            }
        ]
    },
    {
        groupId: 2,
        index: 8,
        title: "PILGRIMAGE: A group of faithful followers needs help.",
        description: "Hello, kindred soul. I'm Acolyte %NAME0% and in behalf of the Church I need someone to bring a group of followers from the %SYSTEM1% system to a sanctuary in %SYSTEM2%. The Church will pay %REWARD% credits for your service.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "The Church is generous." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring a group of followers from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 7 },
                waitingMission: "W2.4.8",
                passengers: [ 3, 7 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring a group of followers to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W2.4"
            }
        ]
    },
    // GalShady Missions ------------------------------------------------------
    // CONTACT
    {
        groupId: 3,
        index: 1,
        title: "URGENT: We need someone to deliver important data to an affiliate.",
        description: "Hi. I'm %NAME0%. I need a ship to deliver some... useful data to %NAME1% in the %SYSTEM1% system. The pay is %REWARD% credits.",
        choices: "mission",
        parcel: "A unlabeled data drive",
        currentTask: 1,
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and deliver 'useful data' to %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W3.1.1",
                urgent: true
            }
        ]
    },
    // TRANSFER
    {
        groupId: 3,
        index: 3,
        title: "SWITCH: We need to move something from a system to another.",
        description: "Hi. I'm %NAME0%. There's a thing in the %SYSTEM1% that has to be moved somewhere else... Talk to %NAME1% for the details. If you accept, the payment is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's better if we do it fast." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system and get 'the thing' from %NAME1%.",
                generate: { systems: 1, names: 1 },
                parcel: "A strange package",
                waitingMission: "W3.2.3.1",
                urgent: true
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring 'the thing' to %NAME2% in the %SYSTEM2% system.",
                hideSystemData: true,
                generate: { systems: 1, names: 1 },
                waitingMission: "W3.2.3.2",
                unaware: true
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 3,
        index: 2,
        title: "JOB OFFER: We need to retrieve a package.",
        description: "Hi. I'm %NAME0%. There's a person in the %SYSTEM1% system that must give me something. The name is %NAME1%. Can you retrieve the package for me? I pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "I must have that package back." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get the package from %NAME1%. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1 },
                parcel: "A somewhat trivial package",
                waitingMission: "W3.3.2.1",
                unaware: true
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring the package to %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W3.3.2.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 3,
        index: 4,
        title: "URGENT: We need to quickly transport an affiliate away from a system.",
        description: "Hi. %NAME1% is actually in the %SYSTEM1% system, but he's in danger and he needs to move away as soon as possible. Destination is %SYSTEM2%. The payment is %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 2,
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                urgent: true,
                waitingMission: "W3.4.4",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                urgent: true,
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 3,
        index: 5,
        title: "SHIP REQUESTED: A business trip.",
        description: "Hi. A group of traders needs a passage from the %SYSTEM1% system to %SYSTEM2%. We will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring a group of traders from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 7 },
                urgent: true,
                waitingMission: "W3.4.5",
                passengers: [ 3, 7 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring a group of trader to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                urgent: true,
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 3,
        index: 9,
        title: "RESCUE: Bring here an affiliate.",
        description: "Hi, we lost contact with %NAME1% a long ago, but recently he reappeared in the %SYSTEM1%. Could you bring him here? Payment is %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W3.4.9.1",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    // CARGO
    {
        groupId: 3,
        index: 6,
        title: "SHIP REQUESTED: I need to move stuff.",
        description: "Hi. I needs to deliver a shipment of %GOODS% to the %SYSTEM1% system. The pay is %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        risk: 2,
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 3,
        index: 7,
        title: "URGENT: I need to regain my goods.",
        description: "Hi, I have a shipment of %GOODS% in the %SYSTEM1% system and I need someone who will take it here. Are you interested? Payment is %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        risk: 1,
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1",
                urgent: true
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3",
                urgent: true
            }
        ]
    },
    {
        groupId: 3,
        index: 8,
        title: "ONLY INTERESTED: Discreet goods relocation.",
        description: "Hi, we need someone to relocate a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM2%. Payment is %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "Commercial stuff, we can say." ]
        },
        risk: 1,
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G3"
            }
        ]
    },
    // GalMedical missions ----------------------------------------------------
    // CONTACT
    {
        groupId: 4,
        index: 1,
        title: "MISSING: Someone to give updates about a medical team.",
        description: "Hello, I'm %NAME0%. We have no news from our medical team in the %SYSTEM1% system. Could you get in touch with them? Doctor %NAME1% is the team leader. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "A holomessage drive",
        customResponses: {
            money: [ "Communication with our teams is essential." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and find Doctor %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W4.1.1",
                unaware: true
            }
        ]
    },
    {
        groupId: 4,
        index: 2,
        title: "MISSING: Someone to give updates about a research group.",
        description: "Hello, I'm %NAME0%. We have no news from our research group in the %SYSTEM1% system. Could you get in touch with them? %NAME1% is the lead researcher. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "A holomessage drive",
        customResponses: {
            money: [ "Communication with our teams is essential." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and find the lead researcher %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W4.1.2",
                unaware: true
            }
        ]
    },
    {
        groupId: 4,
        index: 3,
        title: "MISSING: Someone to give updates about an emergency team.",
        description: "Hello, I'm %NAME0%. We have no news from our emergency team in the %SYSTEM1% system. Could you get in touch with them? Doctor %NAME1% is the head of the team. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "Communication with our teams is essential." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and find the Doctor %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W4.1.1",
                unaware: true
            }
        ]
    },
    // TRANSFER
    {
        groupId: 4,
        index: 5,
        title: "URGENT: A fast ship for transport of rare donor blood.",
        description: "Hi, I'm Doctor %NAME1%. We have an emergency at a hospital on %SYSTEM2%. We need someone who can pick up a special donor blood type from %SYSTEM1% and bring to the hospital. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's an urgent matter." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system and get the donor blood from Doctor %NAME1%. Transport the blood to %SYSTEM2%.",
                generate: { systems: 1, names: 1 },
                parcel: "Special donor blood bags",
                waitingMission: "W4.2.5.1",
                urgent: true
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring the donor blood to Doctor %NAME2% in the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W4.2.5.2",
                urgent: true
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 4,
        index: 4,
        title: "SHIP REQUESTED: We need clinical records from another system.",
        description: "Hello, I'm Doctor %NAME0% and I need someone to bring me back some boxes of documents that have been left to Doctor %NAME1% in the %SYSTEM1% system. I will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's nothing special, really." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get the documents from Doctor %NAME1%. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1 },
                parcel: "Boxes full of medical papers",
                waitingMission: "W4.3.4.1"
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring the documents to Doctor %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W4.3.4.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 4,
        index: 6,
        title: "EMERGENCY: Fast travel for a medic.",
        description: "Hello, I'm Doctor %NAME0% and I need to go quickly to the %SYSTEM1% system. I have to help other teams to contain a viral epidemic. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "It's an urgent matter." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME0% to the %SYSTEM1% system as quickly as you can. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                urgent: true,
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 4,
        index: 7,
        title: "SHIP REQUESTED: Transport for a medical team.",
        description: "Hello, I'm Doctor %NAME0%. I'm looking for someone to transport me and my team to the %SYSTEM1% system. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 3, 7 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "The soon we go, the better." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME0% and his team (%PASSENGERS% people) to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 4,
        index: 8,
        title: "SHIP REQUESTED: Transport for a research team.",
        description: "Hello, I'm Doctor %NAME0%. I'm looking for someone to transport me and my team to the %SYSTEM1% system. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 3, 7 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "The soon we go, the better." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME0% and his team (%PASSENGERS% people) to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 4,
        index: 11,
        title: "EMERGENCY: Need transport for a sick %RACE%.",
        description: "Hello citizen, I'm Doctor %NAME0%. There's a sick %RACE% in the %SYSTEM1% that needs vital cures that we only can provide in our structures. You must pick him up and return back here as fast as possible. His sickness isn't contagious. We will pay you %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        failureDead: true,
        customResponses: {
            money: [ "It's an emergency." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring thw sick %RACE% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1, races: 1 },
                waitingMission: "W4.4.11.1",
                urgent: true,
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring the sick %RACE% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                urgent: true,
                waitingMission: "W4.4.11.2"
            }
        ]
    },
    {
        groupId: 4,
        index: 12,
        title: "EMERGENCY: Need transport for a sick %RACE%.",
        description: "Hello citizen, I'm Doctor %NAME0%. We have a sick %RACE% that we need to move in a specialized hospital in the %SYSTEM1%. His sickness isn't contagious. We will pay you %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 1,
        customResponses: {
            money: [ "It's an emergency." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring thw sick %RACE% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, races: 1 },
                urgent: true,
                waitingMission: "W4.4.11.2"
            }
        ]
    },
    {
        groupId: 4,
        index: 13,
        title: "SHIP REQUESTED: Bring back a medic.",
        description: "Hello, I'm Doctor %NAME0%. Doctor %NAME1% has completed a series of emergency visits and needs someone to get back on %SYSTEM0%. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "Nothing special, really." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Go to the %SYSTEM1% system and bring back Doctor %NAME% to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G4",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring back Doctor %NAME% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 4,
        index: 14,
        title: "SHIP REQUESTED: Bring back a medical team.",
        description: "Hello, I'm Doctor %NAME0%. I'm looking for someone to transport here a medical team from the %SYSTEM1% system. Doctor %NAME1% is the team leader. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "The team has completed its work, and needs to get back home." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME1% and his medical team (%PASSENGERS% people) from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 7 },
                waitingMission: "G4",
                passengers: [ 3, 7 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME1% and his medical team (%PASSENGERS% people) to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 4,
        index: 15,
        title: "SHIP REQUESTED: Bring back a research team.",
        description: "Hello, I'm Doctor %NAME0%. I'm looking for someone to transport here the research team of Doctor %NAME1% from the %SYSTEM1% system. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "The team has completed its studies and we need the data." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME1% and his research team (%PASSENGERS% people) from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 7 },
                waitingMission: "G4",
                passengers: [ 3, 7 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring Doctor %NAME1% and his research team (%PASSENGERS% people) to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    // CARGO
    {
        groupId: 4,
        index: 9,
        title: "SHIPMENT: Need ship for transporting medical equipment.",
        description: "Hello. I'm %NAME0%. We are going to deliver a shipment of %GOODS% to the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "People lives depend on this." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 4,
        index: 10,
        title: "URGENT: We need this stuff as soon as possible!",
        description: "Hello, I'm Doctor %NAME0%. There's shipment of %GOODS% from the %SYSTEM1% that we need quickly. If you accept, we will pay you %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "Timing is essential." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                urgent: true,
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                urgent: true,
                waitingMission: "G3"
            }
        ]
    },
    // GalCivic missions ------------------------------------------------------
    // CONTACT
    {
        groupId: 5,
        index: 1,
        title: "WANTED: A ship to deliver a package.",
        description: "Hello, I'm %NAME0%. I need a ship to deliver a package to %NAME1% in the %SYSTEM1% system. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "A package",
        customResponses: {
            money: [ "[litf_missionResponseMoneyParcel]" ] // this.litf_missionResponseMoneyParcel
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and deliver a package to %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W5.1.1"
            }
        ]
    },
    {
        groupId: 5,
        index: 2,
        title: "NEED HELP: I wish for some news from my family.",
        description: "Hi, I'm %NAME0% and I had no news of my family lately. Can you help me? You should looking for %NAME1%, a relative of mine. I'll pay %REWARD% credits for this.",
        choices: "mission",
        parcel: "A holomessage player",
        currentTask: 1,
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and look for %NAME1%.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W5.1.2",
                unaware: true
            }
        ]
    },
    // TRANSFER

    // RETRIEVE
    {
        groupId: 5,
        index: 3,
        title: "TAKE BACK: I forgotten %ITEM% in another system.",
        description: "Hi, I'm %NAME0%, and I left %ITEM% in the %SYSTEM1% system. You can ask to my friend %NAME1% there. I'll pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "Sentimental value." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get %ITEM% from %NAME1%. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1, items: 1 },
                parcel: "%ITEM%",
                waitingMission: "W5.3.3.1"
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Return %ITEM% to %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W5.3.3.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 5,
        index: 4,
        title: "TAXI JOB: Ship for one.",
        description: "Hello, I'm %NAME0%. I need to go to the %SYSTEM1% system. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "[litf_missionResponseMoneyPassenger]" ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME0% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 5,
        index: 5,
        title: "TAXI JOB: Ship for a group.",
        description: "Hello, I'm %NAME0%. Me and my friends need to go to the %SYSTEM1% system. I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 3, 7 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "[litf_missionResponseMoneyGroup]" ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %PASSENGERS% people to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 5,
        index: 8,
        title: "DISCRETION: Need a passage for a person.",
        description: "Hello, I'm %NAME0%. My friend %NAME1% needs a ship to go from the %SYSTEM1% system to %SYSTEM2%. He is a little paranoid about someone following him. If you accept, the payment is %REWARD%.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "I hope this guarantee a safe passage." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W5.4.8.1",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 5,
        index: 9,
        title: "DISCRETION: Need to transport someone here.",
        description: "Hello, I'm %NAME0%. My friend %NAME1% needs a ship to come here from the %SYSTEM1% system. He is a little paranoid about someone following him. If you accept, the payment is %REWARD%.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "I hope this guarantee a safe passage." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W5.4.8.1",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring %NAME1% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    // CARGO
    {
        groupId: 5,
        index: 6,
        title: "CARGO: Help me moving stuff.",
        description: "Hello. I'm %NAME0%. I need to deliver a shipment of %GOODS% to the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "Nothing special, really." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 5,
        index: 7,
        title: "HELP: I need someone to regain a bunch of stuff.",
        description: "Hello, I'm %NAME0%. I had a shipment of %GOODS% that has been blocked in the %SYSTEM1% system. Now I can retake it but I don't have a ship. Can you do it for me? I'll pay you %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "I don't want to lose more credits." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3"
            }
        ]
    },
    // GalTourism missions ----------------------------------------------------
    // CONTACT
    {
        groupId: 6,
        index: 1,
        title: "URGENT: Need to cancel a booking.",
        description: "Hello, I'm %NAME0%. I had some issue and I have to cancel a booking for a room at the DeLuxor hotel in %SYSTEM1%, but I can't reach the customer care. Can you go and cancel the booking at the hotel reception? I'll give you the necessary documents. %REWARD% credits for the job.",
        choices: "mission",
        currentTask: 1,
        parcel: "A folder of documents",
        customResponses: {
            money: [ "We want to attend this matter without wasting other time." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and cancel %NAME0% booking to the DeLuxor hotel.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W6.1.1",
                unaware: true
            }
        ]
    },
    // TRANSFER
    {
        groupId: 6,
        index: 2,
        title: "HELP NEEDED: Someone to transfer baggage misdirected at another system.",
        description: "Hi, I'm %NAME1%. Because of a travel agency mistake, my friend %NAME2% baggage is currently at the wrong system. You should go to the %SYSTEM1% system and bring the baggage to %SYSTEM2%. I'll give you my friend documents for the reclamation process. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "My friend wants to recover his things as soon as possible." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system, get %NAME2% baggage and bring it to %SYSTEM2%.",
                generate: { systems: 1, names: 1 },
                parcel: "A bunch of baggages and trolleys",
                waitingMission: "W6.2.2.1",
                unaware: true
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring %NAME2% baggage to the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W6.2.2.2"
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 6,
        index: 3,
        title: "HELP NEEDED: Someone to recover baggage misdirected at another system.",
        description: "Hi, I'm %NAME1%. Because of a travel agency mistake, my baggage is currently at the wrong system. You should go to the %SYSTEM1% system and bring back the baggage to me. I'll give you the documents for the reclamation process. The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "I want to recover my things as soon as possible." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system, get %NAME0% baggage and bring it back to %SYSTEM0%.",
                generate: { systems: 1, names: 1 },
                parcel: "A bunch of baggages and trolleys",
                waitingMission: "W6.3.3.1",
                unaware: true
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring %NAME0% baggage back to the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W6.3.3.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 6,
        index: 4,
        title: "HELP US: Group of stranded tourists without passage.",
        description: "Hello, we are a group of tourist and we have lost the travel agency ship for our Hotel in the %SYSTEM1% system. Can you bring us there? I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 3, 7 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "[litf_missionResponseMoneyGroup]" ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring %PASSENGERS% people to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "W6.4"
            }
        ]
    },
    // CARGO
    {
        groupId: 6,
        index: 5,
        title: "DELUXOR: We need to deliver materials.",
        description: "Hello. I'm %NAME0%. We are going to deliver a shipment of %GOODS% to the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "This stuff goes to a DeLuxor hotel." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 6,
        index: 6,
        title: "DELUXOR: Someone to deliver us materials.",
        description: "Hello, I'm %NAME0%. We need a shipment of %GOODS% from the %SYSTEM1%. We pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "We need this shipment for a DeLuxor hotel." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3"
            }
        ]
    },
    // GalShopping missions ---------------------------------------------------
    // CONTACT

    // TRANSFER

    // RETRIEVE

    // TRANSPORT

    // CARGO
    {
        groupId: 7,
        index: 1,
        title: "COMMERCIAL: Need a ship to deliver cargo to another system.",
        description: "Hello. I'm %NAME0%. My business needs to send a shipment of %GOODS% to the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "It's a simple commercial trip." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 7,
        index: 2,
        title: "COMMERCIAL: Need a ship to deliver cargo.",
        description: "Hello. I'm %NAME0%. My business needs to send a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM2%. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "It's a simple commercial trip." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 7,
        index: 3,
        title: "COMMERCIAL: Need a ship to bring cargo here.",
        description: "Hello. I'm %NAME0%. My business needs to bring here a shipment of %GOODS% from the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "It's a simple commercial trip." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3"
            }
        ]
    },
    // GalNature missions -----------------------------------------------------
    // CONTACT

    // TRANSFER

    // RETRIEVE
    {
        groupId: 8,
        index: 1,
        title: "IMPORTANT: Someone with a ship to recover plants specimens.",
        description: "Hello, A botanical facility on %SYSTEM1% has broken down and we need to store some plants specimens. We'll warning of your arrive if you accept. We will pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's an important matter for us." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get the plants specimens. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1 },
                parcel: "A insulated box of plants specimen",
                waitingMission: "W8.3.1.1"
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring the plants specimens to %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W8.3.1.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 8,
        index: 2,
        title: "JOB OFFER: Need ship for transport.",
        description: "Hi, I'm %NAME0%. I need a ship to go to the %SYSTEM1% system. Are you interested? I will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 0,
        customResponses: {
            money: [ "I'm completing a thesis in [litf_missionResponseMoneyNatureJob]." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring naturalist %NAME1% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 8,
        index: 3,
        title: "JOB OFFER: Need ship for transport.",
        description: "Hello, I'm %NAME0%. A naturalist in the %SYSTEM1% needs a passage to %SYSTEM2%. The payment is %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "He's a [litf_missionResponseMoneyNatureJob] expert." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring naturalist %NAME1% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G2",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring naturalist %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 8,
        index: 4,
        title: "JOB OFFER: Need ship for transport.",
        description: "Hi, I'm %NAME0%. We need to bring back a naturalist from the %SYSTEM1% system. We will pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "He's a [litf_missionResponseMoneyNatureJob] scholar." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring naturalist %NAME1% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G2",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring naturalist to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    // CARGO
    {
        groupId: 8,
        index: 5,
        title: "SHIP REQUESTED: Deliver materials to another system.",
        description: "Hi, I'm %NAME0%. We need to deliver a shipment of %GOODS% to the %SYSTEM1% system. Payment is %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "Normal scientific stuff." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 8,
        index: 6,
        title: "STUDY: Looking for a ship to transport materials here.",
        description: "Hello, I'm %NAME0%, and I need the %GOODS% we left in the %SYSTEM1% system. Are you interested? We pay %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "Normal scientific stuff." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3"
            }
        ]
    },
    // GalCulture missions ----------------------------------------------------
    // CONTACT
    {
        groupId: 9,
        index: 1,
        title: "DELIVER: A painting to a buyer.",
        description: "Hello, I'm %NAME0%. I need a ship to transport the '%PAINTING%' painting to a buyer in the %SYSTEM1% system. The buyer name is %NAME1%. I'll pay you %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "The '%PAINTING% painting",
        customResponses: {
            money: [ "It's a really good painting." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and give the '%PAINTING%' painting to %NAME1%.",
                generate: { systems: 1, names: 1, paintings: 1 },
                waitingMission: "W9.1.1"
            }
        ]
    },
    // TRANSFER
    {
        groupId: 9,
        index: 2,
        title: "TRANSFER: Move a painting to its new location.",
        description: "Hello, I'm %NAME0%. We are preparing a new art gallery in the %SYSTEM2% system where we want to display the '%PAINTING%' painting, actually owned by %NAME1% in %SYSTEM1%. Do you mind to proceed to its relocation? We'll pay %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's a really good painting." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% system, get the '%PAINTING%' painting and bring it to %SYSTEM2%.",
                generate: { systems: 1, names: 1, paintings: 1 },
                parcel: "The '%PAINTING% painting",
                waitingMission: "W9.2.2.1"
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring the '%PAINTING%' to the %SYSTEM2% system.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W9.2.2.2"
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 9,
        index: 3,
        title: "RECOVER: A painting from an art restorer.",
        description: "Hello, I'm %NAME0% and I have to retrieve the '%PAINTING%' painting from an art restorer in %SYSTEM1%. I need someone who'll pickup the painting because in this moment I have no way to do it. Interested? The pay is %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's a really good painting." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system, get the '%PAINTING%' painting and return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1, paintings: 1 },
                parcel: "The '%PAINTING% painting",
                waitingMission: "W9.3.3.1",
                unaware: true
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring the '%PAINTING%' painting to %NAME0% in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W9.3.3.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 9,
        index: 4,
        title: "ART: Transport a famous artist to an event.",
        description: "Hello, I'm %NAME1% and I must go to the %SYSTEM1% system for an important artistic event. If you're in, the pay is %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 1,
        customResponses: {
            money: [ "I'm [litf_missionResponseMoneyArtist]" ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring artist %NAME1% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 9,
        index: 5,
        title: "ART: Transport a famous artist to an event.",
        description: "There will be an important art festival in the %SYSTEM2% system, and we need to transport there the controversial %NAME1% from %SYSTEM1%. We can pay %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        customResponses: {
            money: [ "He's [litf_missionResponseMoneyArtist]." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring artist %NAME1% from the %SYSTEM1% system to %SYSTEM2%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G2",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring artist %NAME1% to the %SYSTEM2% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1 },
                waitingMission: "G1"
            }
        ]
    },
    // CARGO
    {
        groupId: 9,
        index: 6,
        title: "HELP NEEDED: Deliver materials to organize an event in another system.",
        description: "Hello, we are organizing a festival in the %SYSTEM1% system and we need to transport a shipment of %GOODS% there. Payment is %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "Nothing special, really." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 9,
        index: 7,
        title: "ORGANIZING: We need a ship to transport equipment.",
        description: "Hello, I'm %NAME0%. We are organizing an event on this system but we need someone to bring here a load of %GOODS% from the %SYSTEM1% system. If you agree, the payment is %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "We need the equipment." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3"
            }
        ]
    },
    // GalGovernment missions -------------------------------------------------
    // CONTACT
    {
        groupId: 10,
        index: 1,
        title: "GOVERNMENT DUTY: Meeting a government agent.",
        description: "Citizen, you're candidate for an important task: meeting a government agent hidden in the %SYSTEM1% system, going with the alias '%NAME1%'. He is requested for reporting duties. We'll give you a safety passcode for the meeting. Government will cover the expenses with %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        parcel: "An encrypted data drive",
        customResponses: {
            money: [ "It's the regulatory government pay." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 1, // CONTACT
                description: "Go to the %SYSTEM1% system, and meet the hidden government agent '%NAME1%'.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W10.1.1",
                unaware: true
            }
        ]
    },
    // TRANSFER
    {
        groupId: 10,
        index: 3,
        title: "GOVERNMENT DUTY: Moving papers between two government consulates.",
        description: "Citizen, you're candidate for an important task: to transfer a set of diplomatic papers from our consulate in the %SYSTEM1% to our consulate in %SYSTEM2%. Government will cover the expenses with %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "It's the regulatory government pay." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 2, // TRANSFER
                description: "Go to the %SYSTEM1% consulate, get the diplomatic papers and bring them to the %SYSTEM2% consulate.",
                generate: { systems: 1, names: 1 },
                parcel: "A folder of diplomatic papers",
                waitingMission: "W10.2.3.1"
            },
            {
                index: 2,
                typeId: 2, // TRANSFER
                description: "Bring the diplomatic papers to the %SYSTEM2% consulate.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W10.2.3.2"
            }
        ]
    },
    // RETRIEVE
    {
        groupId: 10,
        index: 2,
        title: "GOVERNMENT DUTY: Recover papers from another system.",
        description: "Citizen, you're candidate for an important task: to retrieve some dossiers that were stolen by hostile forces! Go to the %SYSTEM1% system, our agent %NAME1% is there waiting for someone to pick up the dossiers. Government will cover the expenses with %REWARD% credits.",
        choices: "mission",
        currentTask: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 3, // RETRIEVE
                description: "Go to the %SYSTEM1% system and get the dossiers from %NAME1%. Return to the %SYSTEM0% system.",
                generate: { systems: 1, names: 1 },
                parcel: "A box full of government dossiers",
                waitingMission: "W10.3.2.1",
                unaware: true
            },
            {
                index: 2,
                typeId: 3, // RETRIEVE
                description: "Bring the dossiers to the governemnt officials in the %SYSTEM0% system.",
                generate: {
                    retrieve: true
                },
                waitingMission: "W10.3.2.2"
            }
        ]
    },
    // TRANSPORT
    {
        groupId: 10,
        index: 4,
        title: "GOVERNMENT DUTY: Transport a government officer to a meeting.",
        description: "Citizen, you're candidate for an important task: to transport officer %NAME1% and his bodyguards to the %SYSTEM1% system, where he has to attend a diplomatic meeting. Government will cover the expenses with %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 3, 7 ],
        firstPassenger: 1,
        risk: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring officer %NAME1% and his bodyguards to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 10,
        index: 5,
        title: "GOVERNMENT DUTY: Transport an agent to its destination.",
        description: "Citizen, you're candidate for an important task: to transport agent %NAME1% to the %SYSTEM1% system. Government will cover the expenses with %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        passengers: [ 1 ],
        firstPassenger: 1,
        risk: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring agent %NAME1% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 10,
        index: 8,
        title: "GOVERNMENT DUTY: Transport a government officer.",
        description: "Citizen, you're candidate for an important task: to transport officer %NAME1% and his bodyguards back from a diplomatic meeting in the %SYSTEM1% system. Government will cover the expenses with %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring back officer %NAME1% and his bodyguards from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 7 },
                waitingMission: "W10.4.8.1",
                passengers: [ 3, 7 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring back officer %NAME1% and his bodyguards to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    {
        groupId: 10,
        index: 9,
        title: "GOVERNMENT DUTY: Return trip for a government agent.",
        description: "Citizen, you're candidate for an important task: to transport back agent %NAME1% from the %SYSTEM1% system. Government will cover the expenses with %REWARD% credits.",
        choices: "transport",
        currentTask: 1,
        risk: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 4, // TRANSPORT
                description: "Bring back agent %NAME1% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, names: 1 },
                waitingMission: "W10.4.9.1",
                passengers: [ 1 ]
            },
            {
                index: 2,
                typeId: 4, // TRANSPORT
                description: "Bring back agent %NAME1% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: {
                    retrieve: true
                },
                waitingMission: "G1"
            }
        ]
    },
    // CARGO
    {
        groupId: 10,
        index: 6,
        title: "GOVERNMENT DUTY: Deliver a shipment to destination.",
        description: "Citizen, you're candidate for an important task: to deliver a shipment of %GOODS% to the %SYSTEM1% system. Government will cover the expenses with %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM1% system. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3"
            }
        ]
    },
    {
        groupId: 10,
        index: 7,
        title: "GOVERNMENT DUTY: Bring here a shipment from another system.",
        description: "Citizen, you're candidate for an important task: to load and bring here a shipment of %GOODS% from the %SYSTEM1% system. Government will cover the expenses with %REWARD% credits.",
        choices: "cargo",
        currentTask: 1,
        customResponses: {
            money: [ "No questions." ]
        },
        tasks: [
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% from the %SYSTEM1% system to %SYSTEM0%. Remember to check the BBS to get your payment.",
                generate: { systems: 1, goods: 1 },
                waitingMission: "G3.1"
            },
            {
                index: 1,
                typeId: 5, // CARGO
                description: "Bring a shipment of %GOODS% to the %SYSTEM0% system. Remember to check the BBS to get your payment.",
                generate: { retrieve: true },
                waitingMission: "G3"
            }
        ]
    }
];

// ----------------------------------------------------------------------------

// Waiting messages - BBS items

this.waitingStore = [
    { groupId: 99, index: 0, title: "LOOK HERE: %NAME1%! I'm awaiting your arrival!", description: "Hello, I'm sorry but you're not the person I'm waiting for. Goodbye.", choices: "hangup" },
    { groupId: 99, index: 0, title: "NOTICE: Please %NAME1% contact me ASAP for completing your work.", description: "Hello, I'm sorry but you're not the person I'm waiting for. Goodbye.", choices: "hangup" },
    { groupId: 99, index: 0, title: "HEY COMMANDER: Are you %NAME1%? I'm awaiting for you!", description: "Hello, I'm sorry but you're not the person I'm waiting for. Goodbye.", choices: "hangup" },
    { groupId: 99, index: 0, title: "ANSWER ME: %NAME1%.", description: "Hello, I'm sorry but you're not the person I'm waiting for. Goodbye.", choices: "hangup" },
    { groupId: 99, index: 0, title: "WAITING: I must to talk to %NAME1%.", description: "Hello, I'm sorry but you're not the person I'm waiting for. Goodbye.", choices: "hangup" },
    { groupId: 99, index: 0, title: "NOTICE: XXXXX Read here %NAME1% XXXXX.", description: "Hello, I'm sorry but you're not the person I'm waiting for. Goodbye.", choices: "hangup" }
];

// Charities - BBS Items

this.charityStore = [
    { groupId: 98, index: 0, title: "FEELING GENEROUS? '%CHARITY%' is here for your unwanted money!", description: "Please select an amount to give to '%CHARITY%'.", showCredits: true, choices: "charity" },
    { groupId: 98, index: 0, title: "GIVE MONEY: Make a good action. Support '%CHARITY%' now!", description: "Please select an amount to give to '%CHARITY%'.", showCredits: true, choices: "charity" },
    { groupId: 98, index: 0, title: "DONATE: '%CHARITY%'. We accept your money. Thanks.", description: "Please select an amount to give to '%CHARITY%'.", showCredits: true, choices: "charity" }
];

// Ads - BBS Items

this.adStore = [
    // 101 - Generic messages and spam
    { groupId: 101, index: 0, title: "NEED HOME: I'm searching for a low-cost apartment. Contact me. Rent only.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 101, index: 0, title: "FREE ROOM: Want to share my room with another person - expenses too.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 101, index: 0, title: "CURIOUS: Do you want to see a real Thargoid? I can help you with that.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 101, index: 0, title: "FORGIVE ME: %NAME1%, are you reading this? Please, please answer me!", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 101, index: 0, title: "LONELY? Do you want to share a bottle of %LIQUOR%? I'm here if you want.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 101, index: 0, title: "HELLO: Hello to everybody! Have a good day!", description: "" },
    { groupId: 101, index: 0, title: "BREATHE: It's important. Don't underestimate gases.", description: "" },
    { groupId: 101, index: 0, title: "HELP: Stasis field. My friend is inside. How to turn off?", description: "" },
    { groupId: 101, index: 0, title: "WARNING: USERS WITH FAKE NAMES WILL BE BANNED FOREVER!", description: "" },
    { groupId: 101, index: 0, title: "IMPORTANT: If you are a time traveler or have the technology I need your help!", description: "" },
    { groupId: 101, index: 0, title: "IT WORKS: Write this message 10 times or you'll get bad luck in 10 days.", description: "" },
    { groupId: 101, index: 0, title: "HINT: How %NAME0% Saved 3000cr Using This Simple Trick", description: "" },
    // 102 - Items messages
    { groupId: 102, index: 0, title: "FOR SALE: I want to give away %ITEM%. Come and pick up.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 102, index: 0, title: "NEED HELP: Someone has seen %ITEM% around here?", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 102, index: 0, title: "WANTED: Searching for %ITEM%. Contact me if you have info.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 102, index: 0, title: "LOST ITEM: Need replacement for %ITEM%. Can you help me?", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 102, index: 0, title: "SELLING: Interested in %ITEM%. Contact me.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    // 103 - Job messages
    { groupId: 103, index: 0, title: "NEED WORK? Open offer for %JOB%. Good position, decent pay. Please contact me.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 103, index: 0, title: "AVAILABLE JOB: We have a free position for %JOB%. Are you interested?", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 103, index: 0, title: "NOW HIRING: Unexpected events force us to search for %JOB%. Contact us if you're available.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 103, index: 0, title: "JOB HERE: Awesome position for %JOB%. Don't miss this opportunity!", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 103, index: 0, title: "AVAILABLE: I'm %JOB%. Currently unemployed, searching for small jobs. Contact me.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 103, index: 0, title: "JOB WANTED: Need job to feed disabled spouse and starving family.", description: "" },
    { groupId: 103, index: 0, title: "UNEMPLOYED CREW: Need work on a starship. Anything considered.", description: "" },
    { groupId: 103, index: 0, title: "NEED WORK: Recently fired for external causes. Looking for any job available.", description: "" },
    { groupId: 103, index: 0, title: "VACANCY REQUIRED: as a crew member on a starship.", description: "" },
    { groupId: 103, index: 0, title: "WANTED: Position on a reputable starship.", description: "" },
    // 104 - Racial messages
    { groupId: 104, index: 0, title: "EVOLUTION: It's time for the %RACE% to change diet?", description: "" },
    { groupId: 104, index: 0, title: "QUESTION: Isn't a %RACE% entitled to the sweat of its brow?", description: "" },
    { groupId: 104, index: 0, title: "CONTEST: Vote the most beautiful %RACE% of the system!!", description: "" },
    { groupId: 104, index: 0, title: "DANGER: Birth race in decline for %RACE%?", description: "" },
    { groupId: 104, index: 0, title: "POLL: What people think when talking about %RACE%?", description: "" },
    { groupId: 104, index: 0, title: "DISCOVER: 42 Life-Changing Style Tips Every %RACE% Should Know", description: "" },
    { groupId: 104, index: 0, title: "INCREDIBLE: This %RACE% will change your life.", description: "" }
];

// Government Specific BBS Items

// 0 - Anarchy, 1 - Feudal, 2 - Multigovernmental, 3 - Dictatorship, 4 - Communist, 5 - Confederacy, 6 - Democracy, 7 - Corporate

this.governmentStore = [
    // Anarchy Specifics
    { groupId: 105, gov: [ 0 ], index: 0, title: "R3M3MB3R: Property is theft!!!", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "W4R: State bigger health system.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "V0T3: Bigger cages! Longer chains!", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "TH1NK: We are the crisis!", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "P30PL3: N07 PR0F175!!!", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "TH3M: Whom the system work for???", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "****: G4LC0P!", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "DEBATE: Someone interested - not screaming slogans?", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "PROPOSAL: Organize something. Use your imagination.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "WAHT: Who enabled strong language censorship HERE? **** ****!!!", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "HINT: How to cope with GalCop officials.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "GUIDE: Ten ways to avoid uncomfortable space encounters.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "OPEN: Alternative botanical growing laboratory course.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "MARKET: Updated listing for unwanted merchandising.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "SOCIAL: Learning to lie in a believable way.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "HELP: A friend of mine has been arrested.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "NET: New and interesting contacts. Free and open.", description: "" },
    { groupId: 105, gov: [ 0 ], index: 0, title: "DARK-BBS: It doesn't exists.", description: "" },
    // Feudal Specifics
    { groupId: 105, gov: [ 1 ], index: 0, title: "EMPIRE: Your effort grows our strength.", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "HAIL: For the glory of the King!", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "LORD: Blessed are the meeks.", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "HERESY: Pagan rituals are BANNED from the Empire!", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "TAXES: Remember the dates, pay your dues.", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "KNIGHTS: No more invaders in OUR sacred lands!", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "PEASANT: You work the land, we protect the land.", description: "" },
    { groupId: 105, gov: [ 1 ], index: 0, title: "TOURNAMENT: Join the festivities and celebrate our englightened monarch.", description: "" },
    // Dictatorship Specifics
    { groupId: 105, gov: [ 3 ], index: 0, title: "WAKE UP: End corruption and immorality.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "TRAITORS: They don't love our system!", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "YOUTH: Join the Revolutionary Forces.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "TRUST: Have faith in your government officials!", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "THINK: What can you do for your system?", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "WORK: Give a future to your children.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "ENEMIES: They could be among us.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "PRIDE: You live in the cradle of civilization!", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "LOOKING FOR: Evicted from communal sector. Searching arrangement.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "MEETING: A civil debate about minor local issues.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "RAID: Last night. Someone heard something?", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "MISSING: I can't find a person anymore.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "CONFORM: There's no need to dissent.", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "MISSING: Someone has seen...", description: "" },
    { groupId: 105, gov: [ 3 ], index: 0, title: "NO PROBLEM: They say. You're happy and it's all okay.", description: "" },
    // Communist Specifics
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: To have more we have to produce more!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: For the Industrial Plan!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: Long live to the Party!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: All power to the Party. Peace to the People. Land to the peasants.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: With great labor we will fulfill the plan.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: All workers choose the Party!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: We grow under the sun of our system.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: Follow the true path, comrades!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: Come to us on the collective farm, comrade!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: Proletarians of all countries, unite!", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "KOMM: Have you signed up with the volunteers?", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "WORK: Reaching the monthly production level.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "WORK: Are we allowed to start a strike?", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "WORK: Who control the industry?", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "WORK: Requiring new machinery - existing one break too often.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "SOCIAL: Weekly political debates.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "SOCIAL: Capitalism is bad. You should know.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "SOCIAL: How much space for innovation?", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "SOCIAL: Discussion on global economic models.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "POLICE: I heard a lot of noise in the near apartments...", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "MISSING: I can't find a person anymore.", description: "" },
    { groupId: 105, gov: [ 4 ], index: 0, title: "MISSING: Someone has seen...", description: "" },
    // Corporate Specifics
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: You should do it now!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Imagine something original!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Buy it, you deserve it!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: There aren't things credits can't buy!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: All is designed for your comfort!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Tastes so good! You can't live without!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Have a break! Do shopping!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Buy, break, replace!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Buy it, you need it!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: You're never spending enough!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: BUY, CONSUME, REPEAT.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AD: Work until expensive become cheap!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "HELP: Credit expired on my credit card. What can I do?", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "POLL: The best debit card on the market today.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "ASKING: How to do more overtime without risking your life.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "THERAPY: I cannot stop working. Too stressed.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "MEDS: Ten products to ease your psychological discomfort.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "MARKET: Global Funds Daily Updates.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "INVESTMENT: What is better? Long term.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "POLL: Can We Guess Your Favourite Product Based On Random Questions?", description: "" },
    // Various
    { groupId: 105, gov: [ 0, 2, 5, 6, 7 ], index: 0, title: "ANSWER NOW: You have just won 999999 credits!!! Talk to me to get your money!!!", description: "" },
    { groupId: 105, gov: [ 0, 2, 5, 6, 7 ], index: 0, title: "IMPORTANT: You could be entitled up to 15340 credits in compensation.", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "SPACEPORT: Baggage reclamation office open for service.", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "DELUXOR HOTELS: Exaggerate luxury for a deluxe holiday!", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "HOSPITAL: Donor blood needed. Do your part.", description: "" },
    { groupId: 105, gov: [ 2, 5, 6 ], index: 0, title: "ART GALLERY: We are closed, but stay updated for our next events!", description: "" },
    { groupId: 105, gov: [ 0, 6, 7 ], index: 0, title: "CITIZEN: Do you trust your government?", description: "" },
    { groupId: 105, gov: [ 1, 2, 5, 7 ], index: 0, title: "PETITION: Ban Low Quality %GOODS% - they're hurting the economy!", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 105, gov: [ 1, 2, 5 ], index: 0, title: "CONCERNED: Don't trust every %GOODS% Vendor. Stay alert.", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 105, gov: [ 1, 2, 5, 7 ], index: 0, title: "PROTEST: Lower taxes for %GOODS%!", description: "Hi, I'm %NAME0%. I'm sorry but this ad is reserved to residents only.", choices: "hangup" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "SOON: The new %MOVIE% movie from the acclaimed director %NAME1%.", description: "Good day. If you're interested in this event, we suggest to ask for more information at the local cultural center. Thanks for your attention.", choices: "hangup" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "IN STORES NOW: The last masterpiece in %MUSIC% by %NAME1%.", description: "Good day. If you're interested in this event, we suggest to ask for more information at the local cultural center. Thanks for your attention.", choices: "hangup" },
    { groupId: 105, gov: [ 2, 5, 6 ], index: 0, title: "ADMIRE: The last collection of %ART% paintings by %NAME1%, now in tour across the galaxy.", description: "Good day. If you're interested in this event, we suggest to ask for more information at the local cultural center. Thanks for your attention.", choices: "hangup" },
    { groupId: 105, gov: [ 0, 2, 3, 4, 5, 6 ], index: 0, title: "ENJOY: Come at the bar, and try our %LIQUOR%! Unforgettable experiences guaranteed!", description: "" },
    { groupId: 105, gov: [ 0, 2, 3, 4, 5, 6 ], index: 0, title: "THE BEST: We have the best %LIQUOR% in the system. Why don't you try it?", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "COOPER CAFE': Come and taste: we serve a damn good coffee!", description: "" },
    { groupId: 105, gov: [ 6, 7 ], index: 0, title: "WEYLAND-YUTANI CORPORATION: Building better worlds.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "ARES MACROTECHNOLGY: Making the world a safer place.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "RENRAKU: Today's solutions to tomorrow's problems.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "WUXING: We're behind everything you do.", description: "" },
    { groupId: 105, gov: [ 5, 6, 7 ], index: 0, title: "OMNICORP: We got the future under control.", description: "" },
    { groupId: 105, gov: [ 5, 6, 7 ], index: 0, title: "TYRELL CORP: More Human Than Human.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "AURITECH SURVEILLANCE: We're keeping an eye out, for you.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "WORLDCOM: For the Greater Good.", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "CENTRAL SERVICES: We do the work! You do the pleasure.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "RENAUTAS: Doing good is good business.", description: "" },
    { groupId: 105, gov: [ 5, 6, 7 ], index: 0, title: "CYBERDYNE SYSTEMS: We are the future.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "YOYODINE: The future begins tomorrow.", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "SOYLENT CORPORATION: Today is Soylent Green day!", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "MULTI-NATIONAL UNITED: Paving the way to unity.", description: "" },
    { groupId: 105, gov: [ 2, 5, 6, 7 ], index: 0, title: "ECORP: Together we can change the world.", description: "" },
    { groupId: 105, gov: [ 7 ], index: 0, title: "MASSIVE DYNAMIC: What do we do? What don't we do.", description: "" }
]

// ----------------------------------------------------------------------------

// Player interaction options arrays

this.hangupChoices = {
    "99_QUIT": "Hang up."
};

this.charityChoices = {
    "01_DONAATE01": "Donate 0.1 credits.",
    "02_DONATE1": "Donate 1 credit.",
    "03_DONATE10": "Donate 10 credits.",
    "04_DONATE100": "Donate 100 credits.",
    "05_DONATE1000": "Donate 1000 credits.",
    "06_DONATE10000": "Donate 10000 credits.",
    "99_QUIT": "Hang up."
};

this.missionChoices = {
    "01_OK": "Ok - agreed.",
    // "02_HOWMANY": "How many of you are there?",
    "03_MONEY": "Why so much money?",
    "04_PROBLEMS": "Will there be any problems?",
    // "05_PERMIT": "Do I need a permit, and if so can I have one?",
    "05_UNAWARE": "Do the recipient will know of my arrival?",
    // "REPEAT": "Could you repeat your original request.",
    "06_MOREMONEY": "I want more money.",
    "07_HALFADVANCE": "I want half the money now.",
    "08_FULLADVANCE": "I want all the money now.",
    // "96_QUIT": "'Hold on while I make room.' then hang up.",
    // "97_QUIT": "'I haven't enough room in my ship' then hang up",
    // "98_QUIT": "'Sorry, I'm not going that way' then hang up",
    "99_QUIT": "Hang up."
};

this.transportChoices = {
    "01_OK": "Ok - agreed.",
    "02_HOWMANY": "How many of you are there?",
    "03_MONEY": "Why so much money?",
    "04_PROBLEMS": "Will there be any problems?",
    // "05_PERMIT": "Do I need a permit, and if so can I have one?",
    // "05_UNAWARE": "Do the recipient will know of my arrival?",
    // "REPEAT": "Could you repeat your original request.",
    "06_MOREMONEY": "I want more money.",
    "07_HALFADVANCE": "I want half the money now.",
    "08_FULLADVANCE": "I want all the money now.",
    // "96_QUIT": "'Hold on while I make room.' then hang up.",
    // "97_QUIT": "'I haven't enough room in my ship' then hang up",
    // "98_QUIT": "'Sorry, I'm not going that way' then hang up",
    "99_QUIT": "Hang up."
};

this.cargoChoices = {
    "01_OK": "Ok - agreed.",
    // "02_HOWMANY": "How many of you are there?",
    "03_MONEY": "Why so much money?",
    "04_PROBLEMS": "Will there be any problems?",
    // "05_PERMIT": "Do I need a permit, and if so can I have one?",
    // "05_UNAWARE": "Do the recipient will know of my arrival?",
    // "REPEAT": "Could you repeat your original request.",
    "06_MOREMONEY": "I want more money.",
    "07_HALFADVANCE": "I want half the money now.",
    "08_FULLADVANCE": "I want all the money now.",
    // "96_QUIT": "'Hold on while I make room.' then hang up.",
    // "97_QUIT": "'I haven't enough room in my ship' then hang up",
    // "98_QUIT": "'Sorry, I'm not going that way' then hang up",
    "99_QUIT": "Hang up."
};
